diff --git a/.github/workflows/flutter_ci.yaml b/.github/workflows/flutter_ci.yaml
index 836d611390..7e064818ef 100644
--- a/.github/workflows/flutter_ci.yaml
+++ b/.github/workflows/flutter_ci.yaml
@@ -22,7 +22,7 @@ on:
- "!frontend/appflowy_tauri/**"
env:
- FLUTTER_VERSION: "3.7.5"
+ FLUTTER_VERSION: "3.10.1"
RUST_TOOLCHAIN: "1.65"
jobs:
diff --git a/.github/workflows/integration_test.yml b/.github/workflows/integration_test.yml
index c646ad14fe..ef8fb0c0b1 100644
--- a/.github/workflows/integration_test.yml
+++ b/.github/workflows/integration_test.yml
@@ -35,7 +35,7 @@ jobs:
- uses: subosito/flutter-action@v2
with:
channel: "stable"
- flutter-version: "3.7.5"
+ flutter-version: "3.10.1"
cache: true
- name: Cache Cargo
diff --git a/.github/workflows/release.yml b/.github/workflows/release.yml
index db107bb9b3..4b02982b76 100644
--- a/.github/workflows/release.yml
+++ b/.github/workflows/release.yml
@@ -6,7 +6,7 @@ on:
- "*"
env:
- FLUTTER_VERSION: "3.7.5"
+ FLUTTER_VERSION: "3.10.1"
RUST_TOOLCHAIN: "1.65"
jobs:
@@ -136,11 +136,7 @@ jobs:
fail-fast: false
matrix:
job:
- - {
- target: x86_64-apple-darwin,
- os: macos-11,
- extra-build-args: "",
- }
+ - { target: x86_64-apple-darwin, os: macos-11, extra-build-args: "" }
steps:
- name: Checkout source code
uses: actions/checkout@v3
diff --git a/.github/workflows/rust_ci.yaml b/.github/workflows/rust_ci.yaml
index d918691086..cd155fcf89 100644
--- a/.github/workflows/rust_ci.yaml
+++ b/.github/workflows/rust_ci.yaml
@@ -22,7 +22,7 @@ on:
env:
CARGO_TERM_COLOR: always
RUST_TOOLCHAIN: "1.65"
- FLUTTER_VERSION: "3.7.5"
+ FLUTTER_VERSION: "3.10.1"
jobs:
test-on-ubuntu:
@@ -80,7 +80,7 @@ jobs:
working-directory: shared-lib
- name: clippy shared-lib
- run: cargo clippy -- -D warnings
+ run: cargo clippy -- -D warnings
working-directory: shared-lib
- name: Run shared-lib tests
diff --git a/.github/workflows/rust_coverage.yml b/.github/workflows/rust_coverage.yml
index be9d09bb4d..83ee935bf6 100644
--- a/.github/workflows/rust_coverage.yml
+++ b/.github/workflows/rust_coverage.yml
@@ -11,7 +11,7 @@ on:
env:
CARGO_TERM_COLOR: always
- FLUTTER_VERSION: "3.7.5"
+ FLUTTER_VERSION: "3.10.1"
RUST_TOOLCHAIN: "1.65"
jobs:
diff --git a/frontend/.vscode/tasks.json b/frontend/.vscode/tasks.json
index 4069eaeef1..cec5290496 100644
--- a/frontend/.vscode/tasks.json
+++ b/frontend/.vscode/tasks.json
@@ -118,7 +118,7 @@
{
"label": "AF: Generate Freezed Files",
"type": "shell",
- "command": "flutter pub run build_runner build --delete-conflicting-outputs",
+ "command": "dart run build_runner build -d",
"options": {
"cwd": "${workspaceFolder}/appflowy_flutter"
}
diff --git a/frontend/appflowy_flutter/Makefile b/frontend/appflowy_flutter/Makefile
index 1f35bf6aaf..6018e6981a 100644
--- a/frontend/appflowy_flutter/Makefile
+++ b/frontend/appflowy_flutter/Makefile
@@ -1,7 +1,7 @@
.PHONY: freeze_build, free_watch
freeze_build:
- flutter pub run build_runner build --delete-conflicting-outputs
+ dart run build_runner build -d
watch:
- flutter pub run build_runner watch
\ No newline at end of file
+ dart run build_runner watch
\ No newline at end of file
diff --git a/frontend/appflowy_flutter/README.md b/frontend/appflowy_flutter/README.md
index 3c1ac42d93..b4bd6916e1 100644
--- a/frontend/appflowy_flutter/README.md
+++ b/frontend/appflowy_flutter/README.md
@@ -1,6 +1,6 @@
AppFlowy_Flutter
diff --git a/frontend/appflowy_flutter/integration_test/util/base.dart b/frontend/appflowy_flutter/integration_test/util/base.dart
index acc4b64e7a..ec7dd07fa0 100644
--- a/frontend/appflowy_flutter/integration_test/util/base.dart
+++ b/frontend/appflowy_flutter/integration_test/util/base.dart
@@ -58,17 +58,21 @@ class TestFolder {
extension AppFlowyTestBase on WidgetTester {
Future initializeAppFlowy() async {
- const MethodChannel('hotkey_manager')
- .setMockMethodCallHandler((MethodCall methodCall) async {
- if (methodCall.method == 'unregisterAll') {
- // do nothing
- }
- });
+ TestDefaultBinaryMessengerBinding.instance.defaultBinaryMessenger
+ .setMockMethodCallHandler(
+ const MethodChannel('hotkey_manager'),
+ (MethodCall methodCall) async {
+ if (methodCall.method == 'unregisterAll') {
+ // do nothing
+ }
+
+ return;
+ },
+ );
await app.main();
await wait(3000);
await pumpAndSettle(const Duration(seconds: 2));
- return;
}
Future tapButton(
diff --git a/frontend/appflowy_flutter/lib/env/env.dart b/frontend/appflowy_flutter/lib/env/env.dart
index e3a57b9848..c52f2f0b13 100644
--- a/frontend/appflowy_flutter/lib/env/env.dart
+++ b/frontend/appflowy_flutter/lib/env/env.dart
@@ -10,32 +10,32 @@ abstract class Env {
varName: 'SUPABASE_URL',
defaultValue: '',
)
- static final supabaseUrl = _Env.supabaseUrl;
+ static final String supabaseUrl = _Env.supabaseUrl;
@EnviedField(
obfuscate: true,
varName: 'SUPABASE_ANON_KEY',
defaultValue: '',
)
- static final supabaseAnonKey = _Env.supabaseAnonKey;
+ static final String supabaseAnonKey = _Env.supabaseAnonKey;
@EnviedField(
obfuscate: true,
varName: 'SUPABASE_KEY',
defaultValue: '',
)
- static final supabaseKey = _Env.supabaseKey;
+ static final String supabaseKey = _Env.supabaseKey;
@EnviedField(
obfuscate: true,
varName: 'SUPABASE_JWT_SECRET',
defaultValue: '',
)
- static final supabaseJwtSecret = _Env.supabaseJwtSecret;
+ static final String supabaseJwtSecret = _Env.supabaseJwtSecret;
@EnviedField(
obfuscate: true,
varName: 'SUPABASE_COLLAB_TABLE',
defaultValue: '',
)
- static final supabaseCollabTable = _Env.supabaseCollabTable;
+ static final String supabaseCollabTable = _Env.supabaseCollabTable;
}
bool get isSupabaseEnable =>
diff --git a/frontend/appflowy_flutter/lib/plugins/database_view/application/field/type_option/select_option_type_option_bloc.dart b/frontend/appflowy_flutter/lib/plugins/database_view/application/field/type_option/select_option_type_option_bloc.dart
index dc5113f469..23f23c8e38 100644
--- a/frontend/appflowy_flutter/lib/plugins/database_view/application/field/type_option/select_option_type_option_bloc.dart
+++ b/frontend/appflowy_flutter/lib/plugins/database_view/application/field/type_option/select_option_type_option_bloc.dart
@@ -5,7 +5,7 @@ import 'dart:async';
import 'package:dartz/dartz.dart';
part 'select_option_type_option_bloc.freezed.dart';
-abstract class ISelectOptionAction {
+abstract mixin class ISelectOptionAction {
Future> Function(String) get insertOption;
List Function(SelectOptionPB) get deleteOption;
diff --git a/frontend/appflowy_flutter/lib/plugins/database_view/application/row/row_cache.dart b/frontend/appflowy_flutter/lib/plugins/database_view/application/row/row_cache.dart
index 59a745d899..0d580071d8 100644
--- a/frontend/appflowy_flutter/lib/plugins/database_view/application/row/row_cache.dart
+++ b/frontend/appflowy_flutter/lib/plugins/database_view/application/row/row_cache.dart
@@ -17,7 +17,7 @@ abstract class RowFieldsDelegate {
void onFieldsChanged(void Function(List) callback);
}
-abstract class RowCacheDelegate {
+abstract mixin class RowCacheDelegate {
UnmodifiableListView get fields;
void onRowDispose();
}
diff --git a/frontend/appflowy_flutter/lib/plugins/database_view/calendar/presentation/toolbar/calendar_toolbar.dart b/frontend/appflowy_flutter/lib/plugins/database_view/calendar/presentation/toolbar/calendar_toolbar.dart
index c04e536d04..f6b18b7322 100644
--- a/frontend/appflowy_flutter/lib/plugins/database_view/calendar/presentation/toolbar/calendar_toolbar.dart
+++ b/frontend/appflowy_flutter/lib/plugins/database_view/calendar/presentation/toolbar/calendar_toolbar.dart
@@ -17,11 +17,11 @@ class CalendarToolbar extends StatelessWidget {
@override
Widget build(BuildContext context) {
- return SizedBox(
+ return const SizedBox(
height: 40,
child: Row(
mainAxisAlignment: MainAxisAlignment.end,
- children: const [
+ children: [
_UnscheduleEventsButton(),
_SettingButton(),
],
diff --git a/frontend/appflowy_flutter/lib/plugins/database_view/grid/presentation/widgets/accessory_menu.dart b/frontend/appflowy_flutter/lib/plugins/database_view/grid/presentation/widgets/accessory_menu.dart
index 898c11951e..22aea38118 100644
--- a/frontend/appflowy_flutter/lib/plugins/database_view/grid/presentation/widgets/accessory_menu.dart
+++ b/frontend/appflowy_flutter/lib/plugins/database_view/grid/presentation/widgets/accessory_menu.dart
@@ -62,9 +62,9 @@ class _AccessoryMenu extends StatelessWidget {
color: AFThemeExtension.of(context).toggleOffFill,
),
const VSpace(6),
- IntrinsicHeight(
+ const IntrinsicHeight(
child: Row(
- children: const [
+ children: [
SortMenu(),
HSpace(6),
FilterMenu(),
diff --git a/frontend/appflowy_flutter/lib/plugins/database_view/widgets/card/cells/card_cell.dart b/frontend/appflowy_flutter/lib/plugins/database_view/widgets/card/cells/card_cell.dart
index 38364fe8fb..624f0bf74a 100644
--- a/frontend/appflowy_flutter/lib/plugins/database_view/widgets/card/cells/card_cell.dart
+++ b/frontend/appflowy_flutter/lib/plugins/database_view/widgets/card/cells/card_cell.dart
@@ -157,7 +157,7 @@ class EditableRowNotifier {
}
}
-abstract class EditableCell {
+abstract mixin class EditableCell {
// Each cell notifier will be bind to the [EditableRowNotifier], which enable
// the row notifier receive its cells event. For example: begin editing the
// cell or end editing the cell.
diff --git a/frontend/appflowy_flutter/lib/plugins/database_view/widgets/card/cells/text_card_cell.dart b/frontend/appflowy_flutter/lib/plugins/database_view/widgets/card/cells/text_card_cell.dart
index 2e497f0a43..9808a9b469 100644
--- a/frontend/appflowy_flutter/lib/plugins/database_view/widgets/card/cells/text_card_cell.dart
+++ b/frontend/appflowy_flutter/lib/plugins/database_view/widgets/card/cells/text_card_cell.dart
@@ -2,7 +2,6 @@ import 'package:appflowy/plugins/database_view/application/cell/cell_controller_
import 'package:flowy_infra_ui/style_widget/text.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
-import 'package:textstyle_extensions/textstyle_extensions.dart';
import '../../row/cell_builder.dart';
import '../bloc/text_card_cell_bloc.dart';
import '../define.dart';
@@ -178,7 +177,10 @@ class _TextCardCellState extends State {
onChanged: (value) => focusChanged(),
onEditingComplete: () => focusNode.unfocus(),
maxLines: null,
- style: Theme.of(context).textTheme.bodyMedium!.size(_fontSize()),
+ style: Theme.of(context)
+ .textTheme
+ .bodyMedium!
+ .copyWith(fontSize: _fontSize()),
decoration: InputDecoration(
// Magic number 4 makes the textField take up the same space as FlowyText
contentPadding: EdgeInsets.symmetric(
diff --git a/frontend/appflowy_flutter/lib/plugins/database_view/widgets/card/cells/url_card_cell.dart b/frontend/appflowy_flutter/lib/plugins/database_view/widgets/card/cells/url_card_cell.dart
index b85cca036d..70b7034e22 100644
--- a/frontend/appflowy_flutter/lib/plugins/database_view/widgets/card/cells/url_card_cell.dart
+++ b/frontend/appflowy_flutter/lib/plugins/database_view/widgets/card/cells/url_card_cell.dart
@@ -2,7 +2,6 @@ import 'package:appflowy/plugins/database_view/application/cell/cell_controller_
import 'package:flowy_infra/size.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
-import 'package:textstyle_extensions/textstyle_extensions.dart';
import '../bloc/url_card_cell_bloc.dart';
import '../define.dart';
@@ -60,12 +59,11 @@ class _URLCardCellState extends State {
textAlign: TextAlign.left,
text: TextSpan(
text: state.content,
- style: Theme.of(context)
- .textTheme
- .bodyMedium!
- .size(widget.style?.fontSize ?? FontSizes.s14)
- .textColor(Theme.of(context).colorScheme.primary)
- .underline,
+ style: Theme.of(context).textTheme.bodyMedium!.copyWith(
+ fontSize: widget.style?.fontSize ?? FontSizes.s14,
+ color: Theme.of(context).colorScheme.primary,
+ decoration: TextDecoration.underline,
+ ),
),
),
),
diff --git a/frontend/appflowy_flutter/lib/plugins/database_view/widgets/card/container/accessory.dart b/frontend/appflowy_flutter/lib/plugins/database_view/widgets/card/container/accessory.dart
index 9b7ce2c63b..4411634a69 100644
--- a/frontend/appflowy_flutter/lib/plugins/database_view/widgets/card/container/accessory.dart
+++ b/frontend/appflowy_flutter/lib/plugins/database_view/widgets/card/container/accessory.dart
@@ -6,7 +6,7 @@ enum AccessoryType {
more,
}
-abstract class CardAccessory implements Widget {
+abstract mixin class CardAccessory implements Widget {
AccessoryType get type;
void onTap(BuildContext context) {}
}
diff --git a/frontend/appflowy_flutter/lib/plugins/database_view/widgets/row/accessory/cell_accessory.dart b/frontend/appflowy_flutter/lib/plugins/database_view/widgets/row/accessory/cell_accessory.dart
index 24d5743bb2..ffe4fcdf3f 100644
--- a/frontend/appflowy_flutter/lib/plugins/database_view/widgets/row/accessory/cell_accessory.dart
+++ b/frontend/appflowy_flutter/lib/plugins/database_view/widgets/row/accessory/cell_accessory.dart
@@ -41,7 +41,7 @@ class GridCellAccessoryBuilder {
}
}
-abstract class GridCellAccessoryState {
+abstract mixin class GridCellAccessoryState {
void onTap();
// The accessory will be hidden if enable() return false;
diff --git a/frontend/appflowy_flutter/lib/plugins/database_view/widgets/row/cells/date_cell/date_editor.dart b/frontend/appflowy_flutter/lib/plugins/database_view/widgets/row/cells/date_cell/date_editor.dart
index 0373b0e8cd..d6bd4cd5d3 100644
--- a/frontend/appflowy_flutter/lib/plugins/database_view/widgets/row/cells/date_cell/date_editor.dart
+++ b/frontend/appflowy_flutter/lib/plugins/database_view/widgets/row/cells/date_cell/date_editor.dart
@@ -17,7 +17,6 @@ import 'package:appflowy_backend/protobuf/flowy-error/errors.pbserver.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:table_calendar/table_calendar.dart';
-import 'package:textstyle_extensions/textstyle_extensions.dart';
import '../../../../grid/presentation/layout/sizes.dart';
import '../../../../grid/presentation/widgets/common/type_option_separator.dart';
import '../../../../grid/presentation/widgets/header/type_option/date.dart';
@@ -198,11 +197,13 @@ class _CellCalendarWidgetState extends State<_CellCalendarWidget> {
outsideDecoration: boxDecoration,
defaultTextStyle: textStyle,
weekendTextStyle: textStyle,
- selectedTextStyle:
- textStyle.textColor(Theme.of(context).colorScheme.surface),
+ selectedTextStyle: textStyle.copyWith(
+ color: Theme.of(context).colorScheme.surface,
+ ),
todayTextStyle: textStyle,
- outsideTextStyle:
- textStyle.textColor(Theme.of(context).disabledColor),
+ outsideTextStyle: textStyle.copyWith(
+ color: Theme.of(context).disabledColor,
+ ),
),
selectedDayPredicate: (day) => isSameDay(state.dateTime, day),
onDaySelected: (selectedDay, focusedDay) {
diff --git a/frontend/appflowy_flutter/lib/plugins/database_view/widgets/row/cells/select_option_cell/text_field.dart b/frontend/appflowy_flutter/lib/plugins/database_view/widgets/row/cells/select_option_cell/text_field.dart
index bd8fcfd602..1963016fd0 100644
--- a/frontend/appflowy_flutter/lib/plugins/database_view/widgets/row/cells/select_option_cell/text_field.dart
+++ b/frontend/appflowy_flutter/lib/plugins/database_view/widgets/row/cells/select_option_cell/text_field.dart
@@ -8,7 +8,6 @@ import 'package:easy_localization/easy_localization.dart';
import 'package:appflowy/generated/locale_keys.g.dart';
import 'package:flutter/services.dart';
import 'package:textfield_tags/textfield_tags.dart';
-import 'package:textstyle_extensions/textstyle_extensions.dart';
import 'extension.dart';
@@ -126,7 +125,7 @@ class _SelectOptionTextFieldState extends State {
hintStyle: Theme.of(context)
.textTheme
.bodySmall!
- .textColor(Theme.of(context).hintColor),
+ .copyWith(color: Theme.of(context).hintColor),
suffixText: _suffixText(),
counterText: "",
prefixIconConstraints:
diff --git a/frontend/appflowy_flutter/lib/plugins/document/presentation/editor_page.dart b/frontend/appflowy_flutter/lib/plugins/document/presentation/editor_page.dart
index 5cc15bab22..33a5810835 100644
--- a/frontend/appflowy_flutter/lib/plugins/document/presentation/editor_page.dart
+++ b/frontend/appflowy_flutter/lib/plugins/document/presentation/editor_page.dart
@@ -6,7 +6,6 @@ import 'package:appflowy/plugins/document/presentation/editor_style.dart';
import 'package:appflowy_editor/appflowy_editor.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
-import 'package:tuple/tuple.dart';
/// Wrapper for the appflowy editor.
class AppFlowyEditorPage extends StatefulWidget {
@@ -88,14 +87,16 @@ class _AppFlowyEditorPageState extends State {
@override
Widget build(BuildContext context) {
- final autoFocusParameters = _computeAutoFocusParameters();
+ final (bool autoFocus, Selection? selection) =
+ _computeAutoFocusParameters();
+
final editor = AppFlowyEditor.custom(
editorState: widget.editorState,
editable: true,
scrollController: scrollController,
// setup the auto focus parameters
- autoFocus: autoFocusParameters.item1,
- focusedSelection: autoFocusParameters.item2,
+ autoFocus: autoFocus,
+ focusedSelection: selection,
// setup the theme
editorStyle: styleCustomizer.style(),
// customize the block builder
@@ -107,7 +108,7 @@ class _AppFlowyEditorPageState extends State {
);
return Center(
- child: Container(
+ child: ConstrainedBox(
constraints: const BoxConstraints(
maxWidth: double.infinity,
),
@@ -246,17 +247,17 @@ class _AppFlowyEditorPageState extends State {
return builders;
}
- Tuple2 _computeAutoFocusParameters() {
+ (bool, Selection?) _computeAutoFocusParameters() {
if (widget.editorState.document.isEmpty) {
- return Tuple2(true, Selection.collapse([0], 0));
+ return (true, Selection.collapse([0], 0));
}
final nodes = widget.editorState.document.root.children
.where((element) => element.delta != null);
final isAllEmpty =
nodes.isNotEmpty && nodes.every((element) => element.delta!.isEmpty);
if (isAllEmpty) {
- return Tuple2(true, Selection.collapse(nodes.first.path, 0));
+ return (true, Selection.collapse(nodes.first.path, 0));
}
- return const Tuple2(false, null);
+ return const (false, null);
}
}
diff --git a/frontend/appflowy_flutter/lib/plugins/document/presentation/editor_plugins/base/link_to_page_widget.dart b/frontend/appflowy_flutter/lib/plugins/document/presentation/editor_plugins/base/link_to_page_widget.dart
index 08d6787a18..44d86af55d 100644
--- a/frontend/appflowy_flutter/lib/plugins/document/presentation/editor_plugins/base/link_to_page_widget.dart
+++ b/frontend/appflowy_flutter/lib/plugins/document/presentation/editor_plugins/base/link_to_page_widget.dart
@@ -2,7 +2,6 @@ import 'package:appflowy/plugins/document/presentation/editor_plugins/base/inser
import 'package:appflowy/workspace/application/app/app_service.dart';
import 'package:appflowy_backend/protobuf/flowy-folder2/view.pb.dart';
import 'package:appflowy_editor/appflowy_editor.dart';
-import 'package:dartz/dartz.dart' as dartz;
import 'package:flowy_infra/image.dart';
import 'package:flowy_infra_ui/style_widget/button.dart';
import 'package:flowy_infra_ui/style_widget/text.dart';
@@ -66,16 +65,16 @@ class _LinkToPageMenuState extends State {
EditorStyle get style => widget.editorState.editorStyle;
int _selectedIndex = 0;
int _totalItems = 0;
- Future>>>? _availableLayout;
- final Map> _items = {};
+ Future)>>? _availableLayout;
+ final Map _items = {};
- Future>>> fetchItems() async {
+ Future)>> fetchItems() async {
final items = await AppBackendService().fetchViews(widget.layoutType);
int index = 0;
- for (final app in items) {
- for (final view in app.value2) {
- _items.putIfAbsent(index, () => dartz.Tuple2(app.value1, view));
+ for (final (app, children) in items) {
+ for (final view in children) {
+ _items.putIfAbsent(index, () => (app, view));
index += 1;
}
}
@@ -158,8 +157,8 @@ class _LinkToPageMenuState extends State {
newSelectedIndex %= _totalItems;
} else if (event.logicalKey == LogicalKeyboardKey.enter) {
widget.onSelected(
- _items[_selectedIndex]!.value1,
- _items[_selectedIndex]!.value2,
+ _items[_selectedIndex]!.$1,
+ _items[_selectedIndex]!.$2,
);
}
@@ -173,15 +172,15 @@ class _LinkToPageMenuState extends State {
Widget _buildListWidget(
BuildContext context,
int selectedIndex,
- Future>>>? items,
+ Future)>>? items,
) {
int index = 0;
- return FutureBuilder>>>(
+ return FutureBuilder)>>(
builder: (context, snapshot) {
if (snapshot.hasData &&
snapshot.connectionState == ConnectionState.done) {
final views = snapshot.data;
- final children = [
+ final List children = [
Padding(
padding: const EdgeInsets.symmetric(vertical: 4),
child: FlowyText.regular(
@@ -191,18 +190,20 @@ class _LinkToPageMenuState extends State {
),
),
];
+
if (views != null && views.isNotEmpty) {
- for (final view in views) {
- if (view.value2.isNotEmpty) {
+ for (final (view, viewChildren) in views) {
+ if (viewChildren.isNotEmpty) {
children.add(
Padding(
padding: const EdgeInsets.symmetric(vertical: 4),
child: FlowyText.regular(
- view.value1.name,
+ view.name,
),
),
);
- for (final value in view.value2) {
+
+ for (final value in viewChildren) {
children.add(
FlowyButton(
isSelected: index == _selectedIndex,
@@ -211,7 +212,7 @@ class _LinkToPageMenuState extends State {
color: Theme.of(context).iconTheme.color,
),
text: FlowyText.regular(value.name),
- onTap: () => widget.onSelected(view.value1, value),
+ onTap: () => widget.onSelected(view, value),
),
);
diff --git a/frontend/appflowy_flutter/lib/plugins/document/presentation/more/font_size_switcher.dart b/frontend/appflowy_flutter/lib/plugins/document/presentation/more/font_size_switcher.dart
index 3740652fe6..40328dc489 100644
--- a/frontend/appflowy_flutter/lib/plugins/document/presentation/more/font_size_switcher.dart
+++ b/frontend/appflowy_flutter/lib/plugins/document/presentation/more/font_size_switcher.dart
@@ -4,7 +4,6 @@ import 'package:flowy_infra_ui/style_widget/text.dart';
import 'package:flutter/material.dart';
import 'package:appflowy/generated/locale_keys.g.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
-import 'package:tuple/tuple.dart';
import 'package:easy_localization/easy_localization.dart';
class FontSizeSwitcher extends StatefulWidget {
@@ -17,10 +16,10 @@ class FontSizeSwitcher extends StatefulWidget {
}
class _FontSizeSwitcherState extends State {
- final List> _fontSizes = [
- Tuple3(LocaleKeys.moreAction_small.tr(), 14.0, false),
- Tuple3(LocaleKeys.moreAction_medium.tr(), 18.0, true),
- Tuple3(LocaleKeys.moreAction_large.tr(), 22.0, false),
+ final List<(String, double, bool)> _fontSizes = [
+ (LocaleKeys.moreAction_small.tr(), 14.0, false),
+ (LocaleKeys.moreAction_medium.tr(), 18.0, true),
+ (LocaleKeys.moreAction_large.tr(), 22.0, false),
];
@override
@@ -42,9 +41,9 @@ class _FontSizeSwitcherState extends State {
),
ToggleButtons(
isSelected:
- _fontSizes.map((e) => e.item2 == state.fontSize).toList(),
+ _fontSizes.map((e) => e.$2 == state.fontSize).toList(),
onPressed: (int index) {
- _updateSelectedFontSize(_fontSizes[index].item2);
+ _updateSelectedFontSize(_fontSizes[index].$2);
},
color: foregroundColor,
borderRadius: const BorderRadius.all(Radius.circular(5)),
@@ -63,8 +62,8 @@ class _FontSizeSwitcherState extends State {
children: _fontSizes
.map(
(e) => Text(
- e.item1,
- style: TextStyle(fontSize: e.item2),
+ e.$1,
+ style: TextStyle(fontSize: e.$2),
),
)
.toList(),
diff --git a/frontend/appflowy_flutter/lib/user/presentation/sign_in_screen.dart b/frontend/appflowy_flutter/lib/user/presentation/sign_in_screen.dart
index fef663f104..59ace71f8c 100644
--- a/frontend/appflowy_flutter/lib/user/presentation/sign_in_screen.dart
+++ b/frontend/appflowy_flutter/lib/user/presentation/sign_in_screen.dart
@@ -273,9 +273,9 @@ class OrContinueWith extends StatelessWidget {
@override
Widget build(BuildContext context) {
- return Row(
+ return const Row(
mainAxisAlignment: MainAxisAlignment.spaceEvenly,
- children: const [
+ children: [
Flexible(
child: Divider(
color: Colors.white,
diff --git a/frontend/appflowy_flutter/lib/user/presentation/skip_log_in_screen.dart b/frontend/appflowy_flutter/lib/user/presentation/skip_log_in_screen.dart
index 8f69763603..7b37e7d226 100644
--- a/frontend/appflowy_flutter/lib/user/presentation/skip_log_in_screen.dart
+++ b/frontend/appflowy_flutter/lib/user/presentation/skip_log_in_screen.dart
@@ -178,8 +178,8 @@ class _SkipLoginMoveWindow extends StatelessWidget
@override
Widget build(BuildContext context) {
- return Row(
- children: const [
+ return const Row(
+ children: [
Expanded(
child: MoveWindowDetector(),
),
diff --git a/frontend/appflowy_flutter/lib/workspace/application/app/app_service.dart b/frontend/appflowy_flutter/lib/workspace/application/app/app_service.dart
index 1974230e26..47475a8e34 100644
--- a/frontend/appflowy_flutter/lib/workspace/application/app/app_service.dart
+++ b/frontend/appflowy_flutter/lib/workspace/application/app/app_service.dart
@@ -85,10 +85,10 @@ class AppBackendService {
return FolderEventMoveItem(payload).send();
}
- Future>>> fetchViews(
+ Future)>> fetchViews(
ViewLayoutPB layoutType,
) async {
- final result = >>[];
+ final result = <(ViewPB, List)>[];
return FolderEventReadCurrentWorkspace().send().then((value) async {
final workspaces = value.getLeftOrNull();
if (workspaces != null) {
@@ -101,7 +101,7 @@ class AppBackendService {
.toList(),
);
if (childViews != null && childViews.isNotEmpty) {
- result.add(Tuple2(view, childViews));
+ result.add((view, childViews));
}
}
}
diff --git a/frontend/appflowy_flutter/lib/workspace/presentation/home/home_stack.dart b/frontend/appflowy_flutter/lib/workspace/presentation/home/home_stack.dart
index 176ff7ac7b..c3795ada86 100644
--- a/frontend/appflowy_flutter/lib/workspace/presentation/home/home_stack.dart
+++ b/frontend/appflowy_flutter/lib/workspace/presentation/home/home_stack.dart
@@ -100,7 +100,7 @@ class FadingIndexedStackState extends State {
}
}
-abstract class NavigationItem {
+abstract mixin class NavigationItem {
Widget get leftBarItem;
Widget? get rightBarItem => null;
diff --git a/frontend/appflowy_flutter/lib/workspace/presentation/widgets/float_bubble/question_bubble.dart b/frontend/appflowy_flutter/lib/workspace/presentation/widgets/float_bubble/question_bubble.dart
index 286e97294c..bd28f3259a 100644
--- a/frontend/appflowy_flutter/lib/workspace/presentation/widgets/float_bubble/question_bubble.dart
+++ b/frontend/appflowy_flutter/lib/workspace/presentation/widgets/float_bubble/question_bubble.dart
@@ -108,15 +108,10 @@ class _DebugToast {
Future _getDeviceInfo() async {
final deviceInfoPlugin = DeviceInfoPlugin();
- final deviceInfo = deviceInfoPlugin.deviceInfo;
+ final deviceInfo = await deviceInfoPlugin.deviceInfo;
- return deviceInfo.then((info) {
- var debugText = "";
- info.toMap().forEach((key, value) {
- debugText = "$debugText$key: $value\n";
- });
- return debugText;
- });
+ return deviceInfo.data.entries
+ .fold('', (prev, el) => "$prev${el.key}: ${el.value}");
}
Future _getDocumentPath() async {
diff --git a/frontend/appflowy_flutter/packages/appflowy_backend/example/pubspec.yaml b/frontend/appflowy_flutter/packages/appflowy_backend/example/pubspec.yaml
index 3488f9f4d1..6faa9793ce 100644
--- a/frontend/appflowy_flutter/packages/appflowy_backend/example/pubspec.yaml
+++ b/frontend/appflowy_flutter/packages/appflowy_backend/example/pubspec.yaml
@@ -6,7 +6,7 @@ description: Demonstrates how to use the appflowy_backend plugin.
publish_to: 'none' # Remove this line if you wish to publish to pub.dev
environment:
- sdk: ">=2.7.0 <3.0.0"
+ sdk: ">=2.12.0 <3.0.0"
dependencies:
flutter:
diff --git a/frontend/appflowy_flutter/packages/appflowy_backend/lib/dispatch/dispatch.dart b/frontend/appflowy_flutter/packages/appflowy_backend/lib/dispatch/dispatch.dart
index cc755286e0..4f911e42e2 100644
--- a/frontend/appflowy_flutter/packages/appflowy_backend/lib/dispatch/dispatch.dart
+++ b/frontend/appflowy_flutter/packages/appflowy_backend/lib/dispatch/dispatch.dart
@@ -8,7 +8,6 @@ import 'package:appflowy_backend/protobuf/flowy-net/network_state.pb.dart';
import 'package:isolates/isolates.dart';
import 'package:isolates/ports.dart';
import 'package:ffi/ffi.dart';
-// ignore: unused_import
import 'package:flutter/services.dart';
import 'dart:async';
import 'dart:typed_data';
diff --git a/frontend/appflowy_flutter/packages/appflowy_backend/pubspec.yaml b/frontend/appflowy_flutter/packages/appflowy_backend/pubspec.yaml
index 3ae7337a34..a2946ad335 100644
--- a/frontend/appflowy_flutter/packages/appflowy_backend/pubspec.yaml
+++ b/frontend/appflowy_flutter/packages/appflowy_backend/pubspec.yaml
@@ -1,17 +1,17 @@
name: appflowy_backend
description: A new flutter plugin project.
version: 0.0.1
-homepage:
+homepage: https://appflowy.io
publish_to: "none"
environment:
- sdk: ">=2.12.0-0 <3.0.0"
+ sdk: ">=2.17.0-0 <3.0.0"
flutter: ">=1.17.0"
dependencies:
flutter:
sdk: flutter
- ffi: ^2.0.1
+ ffi: ^2.0.2
isolates: ^3.0.3+8
protobuf: ^2.0.0
dartz: ^0.10.1
diff --git a/frontend/appflowy_flutter/packages/appflowy_backend/test/appflowy_backend_method_channel_test.dart b/frontend/appflowy_flutter/packages/appflowy_backend/test/appflowy_backend_method_channel_test.dart
index 330319bc32..46807487fd 100644
--- a/frontend/appflowy_flutter/packages/appflowy_backend/test/appflowy_backend_method_channel_test.dart
+++ b/frontend/appflowy_flutter/packages/appflowy_backend/test/appflowy_backend_method_channel_test.dart
@@ -9,13 +9,21 @@ void main() {
TestWidgetsFlutterBinding.ensureInitialized();
setUp(() {
- channel.setMockMethodCallHandler((MethodCall methodCall) async {
- return '42';
- });
+ TestDefaultBinaryMessengerBinding.instance.defaultBinaryMessenger
+ .setMockMethodCallHandler(
+ channel,
+ (MethodCall methodCall) async {
+ return '42';
+ },
+ );
});
tearDown(() {
- channel.setMockMethodCallHandler(null);
+ TestDefaultBinaryMessengerBinding.instance.defaultBinaryMessenger
+ .setMockMethodCallHandler(
+ channel,
+ null,
+ );
});
test('getPlatformVersion', () async {
diff --git a/frontend/appflowy_flutter/packages/appflowy_backend/test/appflowy_backend_test.dart b/frontend/appflowy_flutter/packages/appflowy_backend/test/appflowy_backend_test.dart
index f9bc59d8d0..30e008df61 100644
--- a/frontend/appflowy_flutter/packages/appflowy_backend/test/appflowy_backend_test.dart
+++ b/frontend/appflowy_flutter/packages/appflowy_backend/test/appflowy_backend_test.dart
@@ -8,13 +8,18 @@ void main() {
TestWidgetsFlutterBinding.ensureInitialized();
setUp(() {
- channel.setMockMethodCallHandler((MethodCall methodCall) async {
+ TestDefaultBinaryMessengerBinding.instance.defaultBinaryMessenger
+ .setMockMethodCallHandler(channel, (MethodCall methodCall) async {
return '42';
});
});
tearDown(() {
- channel.setMockMethodCallHandler(null);
+ TestDefaultBinaryMessengerBinding.instance.defaultBinaryMessenger
+ .setMockMethodCallHandler(
+ channel,
+ null,
+ );
});
test('getPlatformVersion', () async {
diff --git a/frontend/appflowy_flutter/packages/appflowy_popover/example/lib/main.dart b/frontend/appflowy_flutter/packages/appflowy_popover/example/lib/main.dart
index a6b09bb4d3..d5f55866b0 100644
--- a/frontend/appflowy_flutter/packages/appflowy_popover/example/lib/main.dart
+++ b/frontend/appflowy_flutter/packages/appflowy_popover/example/lib/main.dart
@@ -78,11 +78,11 @@ class _MyHomePageState extends State {
direction: PopoverDirection.topWithLeftAligned,
),
]),
- Expanded(
+ const Expanded(
child: Column(
mainAxisAlignment: MainAxisAlignment.center,
- children: [
- const ExampleButton(
+ children: [
+ ExampleButton(
label: "Top",
offset: Offset(0, 10),
direction: PopoverDirection.bottomWithCenterAligned,
@@ -91,7 +91,7 @@ class _MyHomePageState extends State {
child: Column(
mainAxisAlignment: MainAxisAlignment.center,
crossAxisAlignment: CrossAxisAlignment.center,
- children: const [
+ children: [
ExampleButton(
label: "Central",
offset: Offset(0, 10),
@@ -100,7 +100,7 @@ class _MyHomePageState extends State {
],
),
),
- const ExampleButton(
+ ExampleButton(
label: "Bottom",
offset: Offset(0, -10),
direction: PopoverDirection.topWithCenterAligned,
@@ -108,15 +108,15 @@ class _MyHomePageState extends State {
],
),
),
- Column(
+ const Column(
children: [
- const ExampleButton(
+ ExampleButton(
label: "Right top",
offset: Offset(0, 10),
direction: PopoverDirection.bottomWithRightAligned,
),
- Expanded(child: Container()),
- const ExampleButton(
+ Expanded(child: SizedBox.shrink()),
+ ExampleButton(
label: "Right bottom",
offset: Offset(0, -10),
direction: PopoverDirection.topWithRightAligned,
diff --git a/frontend/appflowy_flutter/packages/appflowy_popover/pubspec.yaml b/frontend/appflowy_flutter/packages/appflowy_popover/pubspec.yaml
index 7f83c6aee8..137faaccae 100644
--- a/frontend/appflowy_flutter/packages/appflowy_popover/pubspec.yaml
+++ b/frontend/appflowy_flutter/packages/appflowy_popover/pubspec.yaml
@@ -1,11 +1,11 @@
name: appflowy_popover
description: A new Flutter package project.
version: 0.0.1
-homepage:
+homepage: https://appflowy.io
environment:
- sdk: ">=2.19.0 <3.0.0"
- flutter: ">=3.7.0"
+ sdk: ">=3.0.0 <4.0.0"
+ flutter: ">=3.10.1"
dependencies:
flutter:
diff --git a/frontend/appflowy_flutter/packages/flowy_infra/pubspec.yaml b/frontend/appflowy_flutter/packages/flowy_infra/pubspec.yaml
index 4686b7cd00..8991da7ce4 100644
--- a/frontend/appflowy_flutter/packages/flowy_infra/pubspec.yaml
+++ b/frontend/appflowy_flutter/packages/flowy_infra/pubspec.yaml
@@ -1,19 +1,18 @@
name: flowy_infra
description: A new Flutter package project.
version: 0.0.1
-homepage:
+homepage: https://appflowy.io
environment:
- sdk: ">=2.18.0 <3.0.0"
- flutter: ">=3.3.0"
+ sdk: ">=3.0.0 <4.0.0"
+ flutter: ">=3.10.1"
dependencies:
flutter:
sdk: flutter
time: '>=2.0.0'
uuid: ">=2.2.2"
- textstyle_extensions: '2.0.0-nullsafety'
- flutter_svg: ^2.0.2
+ flutter_svg: ^2.0.6
dev_dependencies:
flutter_test:
diff --git a/frontend/appflowy_flutter/packages/flowy_infra_ui/lib/src/flowy_overlay/flowy_overlay.dart b/frontend/appflowy_flutter/packages/flowy_infra_ui/lib/src/flowy_overlay/flowy_overlay.dart
index 4620374069..a35ebc2f2e 100644
--- a/frontend/appflowy_flutter/packages/flowy_infra_ui/lib/src/flowy_overlay/flowy_overlay.dart
+++ b/frontend/appflowy_flutter/packages/flowy_infra_ui/lib/src/flowy_overlay/flowy_overlay.dart
@@ -73,7 +73,7 @@ TransitionBuilder overlayManagerBuilder() {
};
}
-abstract class FlowyOverlayDelegate {
+abstract mixin class FlowyOverlayDelegate {
bool asBarrier() => false;
void didRemove() => {};
}
diff --git a/frontend/appflowy_flutter/packages/flowy_infra_ui/lib/style_widget/text_field.dart b/frontend/appflowy_flutter/packages/flowy_infra_ui/lib/style_widget/text_field.dart
index 01d3834e8f..1a4a89aa8c 100644
--- a/frontend/appflowy_flutter/packages/flowy_infra_ui/lib/style_widget/text_field.dart
+++ b/frontend/appflowy_flutter/packages/flowy_infra_ui/lib/style_widget/text_field.dart
@@ -3,7 +3,6 @@ import 'dart:async';
import 'package:flowy_infra/size.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
-import 'package:textstyle_extensions/textstyle_extensions.dart';
class FlowyTextField extends StatefulWidget {
final String hintText;
@@ -125,7 +124,7 @@ class FlowyTextFieldState extends State {
hintStyle: Theme.of(context)
.textTheme
.bodySmall!
- .textColor(Theme.of(context).hintColor),
+ .copyWith(color: Theme.of(context).hintColor),
suffixText: _suffixText(),
counterText: "",
focusedBorder: OutlineInputBorder(
diff --git a/frontend/appflowy_flutter/packages/flowy_infra_ui/lib/style_widget/text_input.dart b/frontend/appflowy_flutter/packages/flowy_infra_ui/lib/style_widget/text_input.dart
index 6cc843bb74..f7db45d8b2 100644
--- a/frontend/appflowy_flutter/packages/flowy_infra_ui/lib/style_widget/text_input.dart
+++ b/frontend/appflowy_flutter/packages/flowy_infra_ui/lib/style_widget/text_input.dart
@@ -3,7 +3,6 @@ import 'dart:math' as math;
import 'package:flowy_infra/size.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
-import 'package:textstyle_extensions/textstyle_extensions.dart';
class FlowyFormTextInput extends StatelessWidget {
static EdgeInsets kDefaultTextInputPadding =
@@ -221,7 +220,7 @@ class StyledSearchTextInputState extends State {
hintStyle: Theme.of(context)
.textTheme
.bodyMedium!
- .textColor(Theme.of(context).hintColor),
+ .copyWith(color: Theme.of(context).hintColor),
labelText: widget.label,
),
),
diff --git a/frontend/appflowy_flutter/packages/flowy_infra_ui/lib/widget/rounded_input_field.dart b/frontend/appflowy_flutter/packages/flowy_infra_ui/lib/widget/rounded_input_field.dart
index e6ab0810b1..27949fb100 100644
--- a/frontend/appflowy_flutter/packages/flowy_infra_ui/lib/widget/rounded_input_field.dart
+++ b/frontend/appflowy_flutter/packages/flowy_infra_ui/lib/widget/rounded_input_field.dart
@@ -3,7 +3,6 @@ import 'package:flowy_infra_ui/widget/rounded_button.dart';
import 'package:flutter/material.dart';
import 'package:flowy_infra/time/duration.dart';
import 'package:flutter/services.dart';
-import 'package:textstyle_extensions/textstyle_extensions.dart';
class RoundedInputField extends StatefulWidget {
final String? hintText;
@@ -131,7 +130,7 @@ class _RoundedInputFieldState extends State {
hintStyle: Theme.of(context)
.textTheme
.bodySmall!
- .textColor(Theme.of(context).hintColor),
+ .copyWith(color: Theme.of(context).hintColor),
suffixText: _suffixText(),
counterText: "",
enabledBorder: OutlineInputBorder(
diff --git a/frontend/appflowy_flutter/packages/flowy_infra_ui/pubspec.yaml b/frontend/appflowy_flutter/packages/flowy_infra_ui/pubspec.yaml
index 03547676a8..9cc2a26929 100644
--- a/frontend/appflowy_flutter/packages/flowy_infra_ui/pubspec.yaml
+++ b/frontend/appflowy_flutter/packages/flowy_infra_ui/pubspec.yaml
@@ -1,25 +1,24 @@
name: flowy_infra_ui
description: A new flutter plugin project.
version: 0.0.1
-homepage:
+homepage: https://appflowy.io
publish_to: "none"
environment:
- sdk: ">=2.19.0 <3.0.0"
- flutter: ">=3.7.0"
+ sdk: ">=3.0.0 <4.0.0"
+ flutter: ">=3.10.1"
dependencies:
flutter:
sdk: flutter
# Thirdparty packages
- textstyle_extensions: "2.0.0-nullsafety"
dartz:
- provider: ^6.0.1
- styled_widget: "^0.3.1"
- equatable: "^2.0.3"
- animations: ^2.0.0
- loading_indicator: ^3.0.1
+ provider: ^6.0.5
+ styled_widget: ^0.4.1
+ equatable: ^2.0.5
+ animations: ^2.0.7
+ loading_indicator: ^3.1.0
async:
# Federated Platform Interface
diff --git a/frontend/appflowy_flutter/packages/flowy_infra_ui/test/flowy_infra_ui_test.dart b/frontend/appflowy_flutter/packages/flowy_infra_ui/test/flowy_infra_ui_test.dart
index c1297b4c77..0f6c29f573 100644
--- a/frontend/appflowy_flutter/packages/flowy_infra_ui/test/flowy_infra_ui_test.dart
+++ b/frontend/appflowy_flutter/packages/flowy_infra_ui/test/flowy_infra_ui_test.dart
@@ -7,13 +7,18 @@ void main() {
TestWidgetsFlutterBinding.ensureInitialized();
setUp(() {
- channel.setMockMethodCallHandler((MethodCall methodCall) async {
+ TestDefaultBinaryMessengerBinding.instance.defaultBinaryMessenger
+ .setMockMethodCallHandler(channel, (MethodCall methodCall) async {
return '42';
});
});
tearDown(() {
- channel.setMockMethodCallHandler(null);
+ TestDefaultBinaryMessengerBinding.instance.defaultBinaryMessenger
+ .setMockMethodCallHandler(
+ channel,
+ null,
+ );
});
test('getPlatformVersion', () async {});
diff --git a/frontend/appflowy_flutter/pubspec.lock b/frontend/appflowy_flutter/pubspec.lock
index 22d2b9a06d..2b4eeaf2ca 100644
--- a/frontend/appflowy_flutter/pubspec.lock
+++ b/frontend/appflowy_flutter/pubspec.lock
@@ -5,18 +5,18 @@ packages:
dependency: transitive
description:
name: _fe_analyzer_shared
- sha256: "405666cd3cf0ee0a48d21ec67e65406aad2c726d9fa58840d3375e7bdcd32a07"
+ sha256: ae92f5d747aee634b87f89d9946000c2de774be1d6ac3e58268224348cd0101a
url: "https://pub.dev"
source: hosted
- version: "60.0.0"
+ version: "61.0.0"
analyzer:
dependency: transitive
description:
name: analyzer
- sha256: "1952250bd005bacb895a01bf1b4dc00e3ba1c526cf47dca54dfe24979c65f5b3"
+ sha256: ea3d8652bda62982addfd92fdc2d0214e5f82e43325104990d4f4c4a2a313562
url: "https://pub.dev"
source: hosted
- version: "5.12.0"
+ version: "5.13.0"
animations:
dependency: transitive
description:
@@ -29,10 +29,10 @@ packages:
dependency: transitive
description:
name: app_links
- sha256: d572dcdff49c4cfcfa6f315e2683e518ec6eb54e084d01e51d9631a4dcc1b5e8
+ sha256: "16725e716afd0634a5441654b1dda2b6c5557aa230884b5e1f41a5aa546a4cb6"
url: "https://pub.dev"
source: hosted
- version: "3.4.2"
+ version: "3.4.3"
appflowy_backend:
dependency: "direct main"
description:
@@ -53,9 +53,9 @@ packages:
dependency: "direct main"
description:
path: "."
- ref: "09e91c"
- resolved-ref: "09e91c6e09f03f12aa2f499767109e70c4791535"
- url: "https://github.com/LucasXu0/appflowy-editor.git"
+ ref: "30ce149"
+ resolved-ref: "30ce149371c77a8076f3a147fd036114a676f474"
+ url: "https://github.com/AppFlowy-IO/appflowy-editor.git"
source: git
version: "0.1.12"
appflowy_popover:
@@ -69,42 +69,42 @@ packages:
dependency: "direct main"
description:
name: archive
- sha256: "80e5141fafcb3361653ce308776cfd7d45e6e9fbb429e14eec571382c0c5fecb"
+ sha256: "0c8368c9b3f0abbc193b9d6133649a614204b528982bebc7026372d61677ce3a"
url: "https://pub.dev"
source: hosted
- version: "3.3.2"
+ version: "3.3.7"
args:
dependency: transitive
description:
name: args
- sha256: "4cab82a83ffef80b262ddedf47a0a8e56ee6fbf7fe21e6e768b02792034dd440"
+ sha256: c372bb384f273f0c2a8aaaa226dad84dc27c8519a691b888725dec59518ad53a
url: "https://pub.dev"
source: hosted
- version: "2.4.0"
+ version: "2.4.1"
async:
dependency: transitive
description:
name: async
- sha256: bfe67ef28df125b7dddcea62755991f807aa39a2492a23e1550161692950bbe0
+ sha256: "947bfcf187f74dbc5e146c9eb9c0f10c9f8b30743e341481c1e2ed3ecc18c20c"
url: "https://pub.dev"
source: hosted
- version: "2.10.0"
+ version: "2.11.0"
bloc:
dependency: "direct main"
description:
name: bloc
- sha256: "658a5ae59edcf1e58aac98b000a71c762ad8f46f1394c34a52050cafb3e11a80"
+ sha256: "3820f15f502372d979121de1f6b97bfcf1630ebff8fe1d52fb2b0bfa49be5b49"
url: "https://pub.dev"
source: hosted
- version: "8.1.1"
+ version: "8.1.2"
bloc_test:
dependency: "direct dev"
description:
name: bloc_test
- sha256: ffbb60c17ee3d8e3784cb78071088e353199057233665541e8ac6cd438dca8ad
+ sha256: "5f41a3e391c89ccdade81a96233e1e5e5d01564e29e5fe180741fb23579399b9"
url: "https://pub.dev"
source: hosted
- version: "9.1.1"
+ version: "9.1.2"
boolean_selector:
dependency: transitive
description:
@@ -117,10 +117,10 @@ packages:
dependency: transitive
description:
name: build
- sha256: "3fbda25365741f8251b39f3917fb3c8e286a96fd068a5a242e11c2012d495777"
+ sha256: "43865b79fbb78532e4bff7c33087aa43b1d488c4fdef014eaef568af6d8016dc"
url: "https://pub.dev"
source: hosted
- version: "2.3.1"
+ version: "2.4.0"
build_config:
dependency: transitive
description:
@@ -133,34 +133,34 @@ packages:
dependency: transitive
description:
name: build_daemon
- sha256: "757153e5d9cd88253cb13f28c2fb55a537dc31fefd98137549895b5beb7c6169"
+ sha256: "5f02d73eb2ba16483e693f80bee4f088563a820e47d1027d4cdfe62b5bb43e65"
url: "https://pub.dev"
source: hosted
- version: "3.1.1"
+ version: "4.0.0"
build_resolvers:
dependency: transitive
description:
name: build_resolvers
- sha256: "687cf90a3951affac1bd5f9ecb5e3e90b60487f3d9cdc359bb310f8876bb02a6"
+ sha256: db49b8609ef8c81cca2b310618c3017c00f03a92af44c04d310b907b2d692d95
url: "https://pub.dev"
source: hosted
- version: "2.0.10"
+ version: "2.2.0"
build_runner:
dependency: "direct dev"
description:
name: build_runner
- sha256: b0a8a7b8a76c493e85f1b84bffa0588859a06197863dba8c9036b15581fd9727
+ sha256: "220ae4553e50d7c21a17c051afc7b183d28a24a420502e842f303f8e4e6edced"
url: "https://pub.dev"
source: hosted
- version: "2.3.3"
+ version: "2.4.4"
build_runner_core:
dependency: transitive
description:
name: build_runner_core
- sha256: "14febe0f5bac5ae474117a36099b4de6f1dbc52df6c5e55534b3da9591bf4292"
+ sha256: "88a57f2ac99849362e73878334caa9f06ee25f31d2adced882b8337838c84e1e"
url: "https://pub.dev"
source: hosted
- version: "7.2.7"
+ version: "7.2.9"
built_collection:
dependency: transitive
description:
@@ -173,10 +173,10 @@ packages:
dependency: transitive
description:
name: built_value
- sha256: "31b7c748fd4b9adf8d25d72a4c4a59ef119f12876cf414f94f8af5131d5fa2b0"
+ sha256: "7dd62d9faf105c434f3d829bbe9c4be02ec67f5ed94832222116122df67c5452"
url: "https://pub.dev"
source: hosted
- version: "8.4.4"
+ version: "8.6.0"
calendar_view:
dependency: "direct main"
description:
@@ -189,10 +189,10 @@ packages:
dependency: transitive
description:
name: characters
- sha256: e6a326c8af69605aec75ed6c187d06b349707a27fbff8222ca9cc2cff167975c
+ sha256: "04a925763edad70e8443c99234dc3328f442e811f1d8fd1a72f1c8ad0f69a605"
url: "https://pub.dev"
source: hosted
- version: "1.2.1"
+ version: "1.3.0"
charcode:
dependency: "direct main"
description:
@@ -205,10 +205,10 @@ packages:
dependency: transitive
description:
name: checked_yaml
- sha256: "3d1505d91afa809d177efd4eed5bb0eb65805097a1463abdd2add076effae311"
+ sha256: feb6bed21949061731a7a75fc5d2aa727cf160b91af9a3e464c5e3a32e28b5ff
url: "https://pub.dev"
source: hosted
- version: "2.0.2"
+ version: "2.0.3"
clipboard:
dependency: "direct main"
description:
@@ -237,18 +237,18 @@ packages:
dependency: "direct main"
description:
name: collection
- sha256: cfc915e6923fe5ce6e153b0723c753045de46de1b4d63771530504004a45fae0
+ sha256: "4a07be6cb69c84d677a6c3096fcf960cc3285a8330b4603e0d463d15d9bd934c"
url: "https://pub.dev"
source: hosted
- version: "1.17.0"
+ version: "1.17.1"
connectivity_plus:
dependency: "direct main"
description:
name: connectivity_plus
- sha256: "8875e8ed511a49f030e313656154e4bbbcef18d68dfd32eb853fac10bce48e96"
+ sha256: "8599ae9edca5ff96163fca3e36f8e481ea917d1e71cdad912c084b5579913f34"
url: "https://pub.dev"
source: hosted
- version: "3.0.3"
+ version: "4.0.1"
connectivity_plus_platform_interface:
dependency: "direct main"
description:
@@ -269,42 +269,34 @@ packages:
dependency: transitive
description:
name: coverage
- sha256: "525ac94733f9ce82507a050bfd62ad89eb1dcbc56308e1e2e17ab11abeee4a75"
+ sha256: "2fb815080e44a09b85e0f2ca8a820b15053982b2e714b59267719e8a9ff17097"
url: "https://pub.dev"
source: hosted
- version: "1.5.0"
+ version: "1.6.3"
crypto:
dependency: transitive
description:
name: crypto
- sha256: aa274aa7774f8964e4f4f38cc994db7b6158dd36e9187aaceaddc994b35c6c67
+ sha256: ff625774173754681d66daaf4a448684fb04b78f902da9cb3d308c19cc5e8bab
url: "https://pub.dev"
source: hosted
- version: "3.0.2"
+ version: "3.0.3"
csslib:
dependency: transitive
description:
name: csslib
- sha256: b36c7f7e24c0bdf1bf9a3da461c837d1de64b9f8beb190c9011d8c72a3dfd745
+ sha256: "831883fb353c8bdc1d71979e5b342c7d88acfbc643113c14ae51e2442ea0f20f"
url: "https://pub.dev"
source: hosted
- version: "0.17.2"
- cupertino_icons:
- dependency: "direct main"
- description:
- name: cupertino_icons
- sha256: e35129dc44c9118cee2a5603506d823bab99c68393879edb440e0090d07586be
- url: "https://pub.dev"
- source: hosted
- version: "1.0.5"
+ version: "0.17.3"
dart_style:
dependency: transitive
description:
name: dart_style
- sha256: "7a03456c3490394c8e7665890333e91ae8a49be43542b616e414449ac358acd4"
+ sha256: f4f1f73ab3fd2afcbcca165ee601fe980d966af6a21b5970c6c9376955c528ad
url: "https://pub.dev"
source: hosted
- version: "2.2.4"
+ version: "2.3.1"
dartz:
dependency: "direct main"
description:
@@ -325,50 +317,18 @@ packages:
dependency: "direct main"
description:
name: device_info_plus
- sha256: b809c4ed5f7fcdb325ccc70b80ad934677dc4e2aa414bf46859a42bfdfafcbb6
+ sha256: "499c61743e13909c13374a8c209075385858c614b9c0f2487b5f9995eeaf7369"
url: "https://pub.dev"
source: hosted
- version: "4.1.3"
- device_info_plus_linux:
- dependency: transitive
- description:
- name: device_info_plus_linux
- sha256: "77a8b3c4af06bc46507f89304d9f49dfc64b4ae004b994532ed23b34adeae4b3"
- url: "https://pub.dev"
- source: hosted
- version: "3.0.0"
- device_info_plus_macos:
- dependency: transitive
- description:
- name: device_info_plus_macos
- sha256: "37961762fbd46d3620c7b69ca606671014db55fc1b7a11e696fd90ed2e8fe03d"
- url: "https://pub.dev"
- source: hosted
- version: "3.0.0"
+ version: "9.0.1"
device_info_plus_platform_interface:
dependency: transitive
description:
name: device_info_plus_platform_interface
- sha256: "83fdba24fcf6846d3b10f10dfdc8b6c6d7ada5f8ed21d62ea2909c2dfa043773"
+ sha256: d3b01d5868b50ae571cd1dc6e502fc94d956b665756180f7b16ead09e836fd64
url: "https://pub.dev"
source: hosted
- version: "3.0.0"
- device_info_plus_web:
- dependency: transitive
- description:
- name: device_info_plus_web
- sha256: "5890f6094df108181c7a29720bc23d0fd6159f17d82787fac093d1fefcaf6325"
- url: "https://pub.dev"
- source: hosted
- version: "3.0.0"
- device_info_plus_windows:
- dependency: transitive
- description:
- name: device_info_plus_windows
- sha256: "23a2874af0e23ee6e3a2a0ebcecec3a9da13241f2cb93a93a44c8764df123dd7"
- url: "https://pub.dev"
- source: hosted
- version: "4.1.0"
+ version: "7.0.0"
diff_match_patch:
dependency: transitive
description:
@@ -381,10 +341,10 @@ packages:
dependency: "direct main"
description:
name: easy_localization
- sha256: "6a2e99fa0bfe5765bf4c6ca9b137d5de2c75593007178c5e4cd2ae985f870080"
+ sha256: "30ebf25448ffe169e0bd9bc4b5da94faa8398967a2ad2ca09f438be8b6953645"
url: "https://pub.dev"
source: hosted
- version: "3.0.1"
+ version: "3.0.2"
easy_logger:
dependency: transitive
description:
@@ -437,10 +397,10 @@ packages:
dependency: transitive
description:
name: ffi
- sha256: a38574032c5f1dd06c4aee541789906c12ccaab8ba01446e800d9c5b79c4a978
+ sha256: ed5337a5660c506388a9f012be0288fb38b49020ce2b45fe1f8b8323fe429f99
url: "https://pub.dev"
source: hosted
- version: "2.0.1"
+ version: "2.0.2"
file:
dependency: transitive
description:
@@ -453,18 +413,18 @@ packages:
dependency: "direct main"
description:
name: file_picker
- sha256: aeeb811e81c3831124fb9dc1077e42d3837de401f4762dd371cb108e9c9fb2a4
+ sha256: "9d6e95ec73abbd31ec54d0e0df8a961017e165aba1395e462e5b31ea0c165daf"
url: "https://pub.dev"
source: hosted
- version: "5.0.0"
+ version: "5.3.1"
fixnum:
dependency: "direct main"
description:
name: fixnum
- sha256: "04be3e934c52e082558cc9ee21f42f5c1cd7a1262f4c63cd0357c08d5bba81ec"
+ sha256: "25517a4deb0c03aa0f32fd12db525856438902d9c16536311e76cdc57b31d7d1"
url: "https://pub.dev"
source: hosted
- version: "1.0.1"
+ version: "1.1.0"
flowy_infra:
dependency: "direct main"
description:
@@ -502,10 +462,10 @@ packages:
dependency: "direct main"
description:
name: flutter_bloc
- sha256: "434951eea948dbe87f737b674281465f610b8259c16c097b8163ce138749a775"
+ sha256: e74efb89ee6945bcbce74a5b3a5a3376b088e5f21f55c263fc38cbdc6237faae
url: "https://pub.dev"
source: hosted
- version: "8.1.2"
+ version: "8.1.3"
flutter_colorpicker:
dependency: "direct main"
description:
@@ -536,27 +496,27 @@ packages:
dependency: "direct main"
description:
path: "."
- ref: master
- resolved-ref: "77cab5696e756e1e18e26b2a6239c1083f60d6b9"
- url: "https://github.com/LucasXu0/flutter_math_fork.git"
+ ref: de24059
+ resolved-ref: de24059e28c6abb453be42c568f33aae1a4decba
+ url: "https://github.com/xazin/flutter_math_fork.git"
source: git
version: "0.6.3+1"
flutter_plugin_android_lifecycle:
dependency: transitive
description:
name: flutter_plugin_android_lifecycle
- sha256: c224ac897bed083dabf11f238dd11a239809b446740be0c2044608c50029ffdf
+ sha256: "950e77c2bbe1692bc0874fc7fb491b96a4dc340457f4ea1641443d0a6c1ea360"
url: "https://pub.dev"
source: hosted
- version: "2.0.9"
+ version: "2.0.15"
flutter_svg:
dependency: "direct main"
description:
name: flutter_svg
- sha256: f991fdb1533c3caeee0cdc14b04f50f0c3916f0dbcbc05237ccbe4e3c6b93f3f
+ sha256: "6ff8c902c8056af9736de2689f63f81c42e2d642b9f4c79dbf8790ae48b63012"
url: "https://pub.dev"
source: hosted
- version: "2.0.5"
+ version: "2.0.6"
flutter_test:
dependency: "direct dev"
description: flutter
@@ -571,18 +531,18 @@ packages:
dependency: "direct main"
description:
name: fluttertoast
- sha256: "2f9c4d3f4836421f7067a28f8939814597b27614e021da9d63e5d3fb6e212d25"
+ sha256: "474f7d506230897a3cd28c965ec21c5328ae5605fc9c400cd330e9e9d6ac175c"
url: "https://pub.dev"
source: hosted
- version: "8.2.1"
+ version: "8.2.2"
freezed:
dependency: "direct dev"
description:
name: freezed
- sha256: "4179d41127bc7a67dc3f58ceec1d22f1cdf10470653cb86eda2a63f81b4920c7"
+ sha256: "2edb9ef971d0f803860ecd9084afd48c717d002141ad77b69be3e976bee7190e"
url: "https://pub.dev"
source: hosted
- version: "2.2.0"
+ version: "2.3.4"
freezed_annotation:
dependency: "direct main"
description:
@@ -608,50 +568,50 @@ packages:
dependency: transitive
description:
name: functions_client
- sha256: "26059c5fb000ffd0986ae3144d43c2a6f54931610fd61c2584e18e308c7eaa52"
+ sha256: "578537de508c62c2875a6fdaa5dc71033283551ac7a32b8b8ef405c6c5823273"
url: "https://pub.dev"
source: hosted
- version: "1.2.1"
+ version: "1.3.0"
get_it:
dependency: "direct main"
description:
name: get_it
- sha256: "290fde3a86072e4b37dbb03c07bec6126f0ecc28dad403c12ffe2e5a2d751ab7"
+ sha256: "529de303c739fca98cd7ece5fca500d8ff89649f1bb4b4e94fb20954abcd7468"
url: "https://pub.dev"
source: hosted
- version: "7.2.0"
+ version: "7.6.0"
glob:
dependency: transitive
description:
name: glob
- sha256: c51b4fdfee4d281f49b8c957f1add91b815473597f76bcf07377987f66a55729
+ sha256: "0e7014b3b7d4dac1ca4d6114f82bf1782ee86745b9b42a92c9289c23d8a0ab63"
url: "https://pub.dev"
source: hosted
- version: "2.1.0"
+ version: "2.1.2"
google_fonts:
dependency: "direct main"
description:
name: google_fonts
- sha256: "927573f2e8a8d65c17931e21918ad0ab0666b1b636537de7c4932bdb487b190f"
+ sha256: "2776c66b3e97c6cdd58d1bd3281548b074b64f1fd5c8f82391f7456e38849567"
url: "https://pub.dev"
source: hosted
- version: "4.0.3"
+ version: "4.0.5"
gotrue:
dependency: transitive
description:
name: gotrue
- sha256: c08f5ac76dcae2dd06cc7f8e80a8ede12c66454fef06caac3b191c8c7a603811
+ sha256: "3306606658484a05fc885aea15f9fa65bcc28194f35ef294de3a34d01393b928"
url: "https://pub.dev"
source: hosted
- version: "1.7.1"
+ version: "1.8.0"
graphs:
dependency: transitive
description:
name: graphs
- sha256: f9e130f3259f52d26f0cfc0e964513796dafed572fa52e45d2f8d6ca14db39b2
+ sha256: aedc5a15e78fc65a6e23bcd927f24c64dd995062bcd1ca6eda65a3cff92a4d19
url: "https://pub.dev"
source: hosted
- version: "2.2.0"
+ version: "2.3.1"
highlight:
dependency: "direct main"
description:
@@ -688,18 +648,18 @@ packages:
dependency: transitive
description:
name: html
- sha256: "79d498e6d6761925a34ee5ea8fa6dfef38607781d2fa91e37523474282af55cb"
+ sha256: "58e3491f7bf0b6a4ea5110c0c688877460d1a6366731155c4a4580e7ded773e8"
url: "https://pub.dev"
source: hosted
- version: "0.15.2"
+ version: "0.15.3"
http:
dependency: "direct main"
description:
name: http
- sha256: "6aa2946395183537c8b880962d935877325d6a09a2867c3970c05c0fed6ac482"
+ sha256: "4c3f04bfb64d3efd508d06b41b825542f08122d30bda4933fb95c069d22a4fa3"
url: "https://pub.dev"
source: hosted
- version: "0.13.5"
+ version: "1.0.0"
http_multi_server:
dependency: transitive
description:
@@ -725,10 +685,10 @@ packages:
dependency: "direct main"
description:
name: intl
- sha256: "910f85bce16fb5c6f614e117efa303e85a1731bb0081edf3604a2ae6e9a3cc91"
+ sha256: a3715e3bc90294e971cb7dc063fbf3cd9ee0ebf8604ffeafabd9e6f16abbdbe6
url: "https://pub.dev"
source: hosted
- version: "0.17.0"
+ version: "0.18.0"
intl_utils:
dependency: transitive
description:
@@ -757,26 +717,26 @@ packages:
dependency: transitive
description:
name: js
- sha256: "5528c2f391ededb7775ec1daa69e65a2d61276f7552de2b5f7b8d34ee9fd4ab7"
+ sha256: f2c445dce49627136094980615a031419f7f3eb393237e4ecd97ac15dea343f3
url: "https://pub.dev"
source: hosted
- version: "0.6.5"
+ version: "0.6.7"
json_annotation:
dependency: "direct main"
description:
name: json_annotation
- sha256: "3520fa844009431b5d4491a5a778603520cdc399ab3406332dcc50f93547258c"
+ sha256: b10a7b2ff83d83c777edba3c6a0f97045ddadd56c944e1a23a3fdf43a1bf4467
url: "https://pub.dev"
source: hosted
- version: "4.7.0"
+ version: "4.8.1"
json_serializable:
dependency: "direct dev"
description:
name: json_serializable
- sha256: f3c2c18a7889580f71926f30c1937727c8c7d4f3a435f8f5e8b0ddd25253ef5d
+ sha256: "61a60716544392a82726dd0fa1dd6f5f1fd32aec66422b6e229e7b90d52325c4"
url: "https://pub.dev"
source: hosted
- version: "6.5.4"
+ version: "6.7.0"
jwt_decode:
dependency: transitive
description:
@@ -805,10 +765,10 @@ packages:
dependency: transitive
description:
name: lints
- sha256: "5e4a9cd06d447758280a8ac2405101e0e2094d2a1dbdd3756aec3fe7775ba593"
+ sha256: "6b0206b0bf4f04961fc5438198ccb3a885685cd67d4d4a32cc20ad7f8adbe015"
url: "https://pub.dev"
source: hosted
- version: "2.0.1"
+ version: "2.1.0"
loading_indicator:
dependency: transitive
description:
@@ -829,26 +789,26 @@ packages:
dependency: transitive
description:
name: logging
- sha256: "04094f2eb032cbb06c6f6e8d3607edcfcb0455e2bb6cbc010cb01171dcb64e6d"
+ sha256: "623a88c9594aa774443aa3eb2d41807a48486b5613e67599fb4c41c0ad47c340"
url: "https://pub.dev"
source: hosted
- version: "1.1.1"
+ version: "1.2.0"
markdown:
dependency: transitive
description:
name: markdown
- sha256: b3c60dee8c2af50ad0e6e90cceba98e47718a6ee0a7a6772c77846a0cc21f78b
+ sha256: "8e332924094383133cee218b676871f42db2514f1f6ac617b6cf6152a7faab8e"
url: "https://pub.dev"
source: hosted
- version: "7.0.1"
+ version: "7.1.0"
matcher:
dependency: transitive
description:
name: matcher
- sha256: "16db949ceee371e9b99d22f88fa3a73c4e59fd0afed0bd25fc336eb76c198b72"
+ sha256: "6501fbd55da300384b768785b83e5ce66991266cec21af89ab9ae7f5ce1c4cbb"
url: "https://pub.dev"
source: hosted
- version: "0.12.13"
+ version: "0.12.15"
material_color_utilities:
dependency: transitive
description:
@@ -861,10 +821,10 @@ packages:
dependency: transitive
description:
name: meta
- sha256: "6c268b42ed578a53088d834796959e4a1814b5e9e164f147f580a386e5decf42"
+ sha256: "3c74dbf8763d36539f114c799d8a2d87343b5067e9d796ca22b5eb8437090ee3"
url: "https://pub.dev"
source: hosted
- version: "1.8.0"
+ version: "1.9.1"
mime:
dependency: transitive
description:
@@ -925,58 +885,26 @@ packages:
dependency: "direct main"
description:
name: package_info_plus
- sha256: f62d7253edc197fe3c88d7c2ddab82d68f555e778d55390ccc3537eca8e8d637
+ sha256: "28386bbe89ab5a7919a47cea99cdd1128e5a6e0bbd7eaafe20440ead84a15de3"
url: "https://pub.dev"
source: hosted
- version: "1.4.3+1"
- package_info_plus_linux:
- dependency: transitive
- description:
- name: package_info_plus_linux
- sha256: "04b575f44233d30edbb80a94e57cad9107aada334fc02aabb42b6becd13c43fc"
- url: "https://pub.dev"
- source: hosted
- version: "1.0.5"
- package_info_plus_macos:
- dependency: transitive
- description:
- name: package_info_plus_macos
- sha256: a2ad8b4acf4cd479d4a0afa5a74ea3f5b1c7563b77e52cc32b3ee6956d5482a6
- url: "https://pub.dev"
- source: hosted
- version: "1.3.0"
+ version: "4.0.1"
package_info_plus_platform_interface:
dependency: transitive
description:
name: package_info_plus_platform_interface
- sha256: f7a0c8f1e7e981bc65f8b64137a53fd3c195b18d429fba960babc59a5a1c7ae8
+ sha256: "9bc8ba46813a4cc42c66ab781470711781940780fd8beddd0c3da62506d3a6c6"
url: "https://pub.dev"
source: hosted
- version: "1.0.2"
- package_info_plus_web:
- dependency: transitive
- description:
- name: package_info_plus_web
- sha256: f0829327eb534789e0a16ccac8936a80beed4e2401c4d3a74f3f39094a822d3b
- url: "https://pub.dev"
- source: hosted
- version: "1.0.6"
- package_info_plus_windows:
- dependency: transitive
- description:
- name: package_info_plus_windows
- sha256: "79524f11c42dd9078b96d797b3cf79c0a2883a50c4920dc43da8562c115089bc"
- url: "https://pub.dev"
- source: hosted
- version: "2.1.0"
+ version: "2.0.1"
path:
dependency: "direct main"
description:
name: path
- sha256: db9d4f58c908a4ba5953fcee2ae317c94889433e5024c27ce74a37f94267945b
+ sha256: "8829d8a55c13fc0e37127c29fedf290c102f4e40ae94ada574091fe0ff96c917"
url: "https://pub.dev"
source: hosted
- version: "1.8.2"
+ version: "1.8.3"
path_parsing:
dependency: transitive
description:
@@ -989,34 +917,34 @@ packages:
dependency: "direct main"
description:
name: path_provider
- sha256: c7edf82217d4b2952b2129a61d3ad60f1075b9299e629e149a8d2e39c2e6aad4
+ sha256: "3087813781ab814e4157b172f1a11c46be20179fcc9bea043e0fba36bc0acaa2"
url: "https://pub.dev"
source: hosted
- version: "2.0.14"
+ version: "2.0.15"
path_provider_android:
dependency: transitive
description:
name: path_provider_android
- sha256: "019f18c9c10ae370b08dce1f3e3b73bc9f58e7f087bb5e921f06529438ac0ae7"
+ sha256: "2cec049d282c7f13c594b4a73976b0b4f2d7a1838a6dd5aaf7bd9719196bee86"
url: "https://pub.dev"
source: hosted
- version: "2.0.24"
+ version: "2.0.27"
path_provider_foundation:
dependency: transitive
description:
name: path_provider_foundation
- sha256: "12eee51abdf4d34c590f043f45073adbb45514a108bd9db4491547a2fd891059"
+ sha256: "1995d88ec2948dac43edf8fe58eb434d35d22a2940ecee1a9fefcd62beee6eb3"
url: "https://pub.dev"
source: hosted
- version: "2.2.0"
+ version: "2.2.3"
path_provider_linux:
dependency: transitive
description:
name: path_provider_linux
- sha256: "2ae08f2216225427e64ad224a24354221c2c7907e448e6e0e8b57b1eb9f10ad1"
+ sha256: ffbb8cc9ed2c9ec0e4b7a541e56fd79b138e8f47d2fb86815f15358a349b3b57
url: "https://pub.dev"
source: hosted
- version: "2.1.10"
+ version: "2.1.11"
path_provider_platform_interface:
dependency: transitive
description:
@@ -1029,10 +957,10 @@ packages:
dependency: transitive
description:
name: path_provider_windows
- sha256: f53720498d5a543f9607db4b0e997c4b5438884de25b0f73098cc2671a51b130
+ sha256: d3f80b32e83ec208ac95253e0cd4d298e104fbc63cb29c5c69edaed43b0c69d6
url: "https://pub.dev"
source: hosted
- version: "2.1.5"
+ version: "2.1.6"
percent_indicator:
dependency: "direct main"
description:
@@ -1045,10 +973,10 @@ packages:
dependency: transitive
description:
name: petitparser
- sha256: "49392a45ced973e8d94a85fdb21293fbb40ba805fc49f2965101ae748a3683b4"
+ sha256: cb3798bef7fc021ac45b308f4b51208a152792445cce0448c9a4ba5879dd8750
url: "https://pub.dev"
source: hosted
- version: "5.1.0"
+ version: "5.4.0"
platform:
dependency: transitive
description:
@@ -1065,6 +993,14 @@ packages:
url: "https://pub.dev"
source: hosted
version: "2.1.4"
+ pointycastle:
+ dependency: transitive
+ description:
+ name: pointycastle
+ sha256: "7c1e5f0d23c9016c5bbd8b1473d0d3fb3fc851b876046039509e18e0c7485f2c"
+ url: "https://pub.dev"
+ source: hosted
+ version: "3.7.3"
pool:
dependency: transitive
description:
@@ -1077,10 +1013,10 @@ packages:
dependency: transitive
description:
name: postgrest
- sha256: "7b91eb7b40621d07aaae687f47f3032f30e1b86a9ccebfcfca52d001223f8b6e"
+ sha256: "42abd4bf3322af3eb0d286ca2fca7cc28baae52b805761dfa7ab0d206ee072a3"
url: "https://pub.dev"
source: hosted
- version: "1.2.4"
+ version: "1.3.0"
process:
dependency: transitive
description:
@@ -1109,26 +1045,26 @@ packages:
dependency: transitive
description:
name: pub_semver
- sha256: "307de764d305289ff24ad257ad5c5793ce56d04947599ad68b3baa124105fc17"
+ sha256: "40d3ab1bbd474c4c2328c91e3a7df8c6dd629b79ece4c4bd04bee496a224fb0c"
url: "https://pub.dev"
source: hosted
- version: "2.1.3"
+ version: "2.1.4"
pubspec_parse:
dependency: transitive
description:
name: pubspec_parse
- sha256: "75f6614d6dde2dc68948dffbaa4fe5dae32cd700eb9fb763fe11dfb45a3c4d0a"
+ sha256: c63b2876e58e194e4b0828fcb080ad0e06d051cb607a6be51a9e084f47cb9367
url: "https://pub.dev"
source: hosted
- version: "1.2.1"
+ version: "1.2.3"
realtime_client:
dependency: transitive
description:
name: realtime_client
- sha256: "0f2614f72e5639ddd7abc3dede336f23554f9f744d0b064d41009f9ca94a53d2"
+ sha256: "13f6a62244bca7562b47658e3f92e5eeeb79a46d58ad4a97ad536e4ba5e97086"
url: "https://pub.dev"
source: hosted
- version: "1.0.4"
+ version: "1.1.0"
reorderables:
dependency: "direct main"
description:
@@ -1141,10 +1077,10 @@ packages:
dependency: transitive
description:
name: retry
- sha256: a8a1e475a100a0bdc73f529ca8ea1e9c9c76bec8ad86a1f47780139a34ce7aea
+ sha256: "822e118d5b3aafed083109c72d5f484c6dc66707885e07c0fbcb8b986bba7efc"
url: "https://pub.dev"
source: hosted
- version: "3.1.1"
+ version: "3.1.2"
rich_clipboard:
dependency: transitive
description:
@@ -1157,10 +1093,10 @@ packages:
dependency: transitive
description:
name: rich_clipboard_android
- sha256: "1388bad7748791818aa5b822df2f3449fff34785b266fa6ca4cbc7cd24342871"
+ sha256: "72725b248d5359a7ad6db2fea5aef921015ba9a00af275cbce3721a4fef20356"
url: "https://pub.dev"
source: hosted
- version: "1.0.0"
+ version: "1.0.1"
rich_clipboard_ios:
dependency: transitive
description:
@@ -1229,90 +1165,90 @@ packages:
dependency: "direct main"
description:
name: shared_preferences
- sha256: "78528fd87d0d08ffd3e69551173c026e8eacc7b7079c82eb6a77413957b7e394"
+ sha256: "16d3fb6b3692ad244a695c0183fca18cf81fd4b821664394a781de42386bf022"
url: "https://pub.dev"
source: hosted
- version: "2.0.20"
+ version: "2.1.1"
shared_preferences_android:
dependency: transitive
description:
name: shared_preferences_android
- sha256: ad423a80fe7b4e48b50d6111b3ea1027af0e959e49d485712e134863d9c1c521
+ sha256: "6478c6bbbecfe9aced34c483171e90d7c078f5883558b30ec3163cf18402c749"
url: "https://pub.dev"
source: hosted
- version: "2.0.17"
+ version: "2.1.4"
shared_preferences_foundation:
dependency: transitive
description:
name: shared_preferences_foundation
- sha256: "1e755f8583229f185cfca61b1d80fb2344c9d660e1c69ede5450d8f478fa5310"
+ sha256: e014107bb79d6d3297196f4f2d0db54b5d1f85b8ea8ff63b8e8b391a02700feb
url: "https://pub.dev"
source: hosted
- version: "2.1.5"
+ version: "2.2.2"
shared_preferences_linux:
dependency: transitive
description:
name: shared_preferences_linux
- sha256: "3a59ed10890a8409ad0faad7bb2957dab4b92b8fbe553257b05d30ed8af2c707"
+ sha256: "9d387433ca65717bbf1be88f4d5bb18f10508917a8fa2fb02e0fd0d7479a9afa"
url: "https://pub.dev"
source: hosted
- version: "2.1.5"
+ version: "2.2.0"
shared_preferences_platform_interface:
dependency: transitive
description:
name: shared_preferences_platform_interface
- sha256: "824bfd02713e37603b2bdade0842e47d56e7db32b1dcdd1cae533fb88e2913fc"
+ sha256: fb5cf25c0235df2d0640ac1b1174f6466bd311f621574997ac59018a6664548d
url: "https://pub.dev"
source: hosted
- version: "2.1.1"
+ version: "2.2.0"
shared_preferences_web:
dependency: transitive
description:
name: shared_preferences_web
- sha256: "0dc2633f215a3d4aa3184c9b2c5766f4711e4e5a6b256e62aafee41f89f1bfb8"
+ sha256: "74083203a8eae241e0de4a0d597dbedab3b8fef5563f33cf3c12d7e93c655ca5"
url: "https://pub.dev"
source: hosted
- version: "2.0.6"
+ version: "2.1.0"
shared_preferences_windows:
dependency: transitive
description:
name: shared_preferences_windows
- sha256: "71bcd669bb9cdb6b39f22c4a7728b6d49e934f6cba73157ffa5a54f1eed67436"
+ sha256: "5e588e2efef56916a3b229c3bfe81e6a525665a454519ca51dbcc4236a274173"
url: "https://pub.dev"
source: hosted
- version: "2.1.5"
+ version: "2.2.0"
shelf:
dependency: transitive
description:
name: shelf
- sha256: c24a96135a2ccd62c64b69315a14adc5c3419df63b4d7c05832a346fdb73682c
+ sha256: ad29c505aee705f41a4d8963641f91ac4cee3c8fad5947e033390a7bd8180fa4
url: "https://pub.dev"
source: hosted
- version: "1.4.0"
+ version: "1.4.1"
shelf_packages_handler:
dependency: transitive
description:
name: shelf_packages_handler
- sha256: aef74dc9195746a384843102142ab65b6a4735bb3beea791e63527b88cc83306
+ sha256: "89f967eca29607c933ba9571d838be31d67f53f6e4ee15147d5dc2934fee1b1e"
url: "https://pub.dev"
source: hosted
- version: "3.0.1"
+ version: "3.0.2"
shelf_static:
dependency: transitive
description:
name: shelf_static
- sha256: e792b76b96a36d4a41b819da593aff4bdd413576b3ba6150df5d8d9996d2e74c
+ sha256: a41d3f53c4adf0f57480578c1d61d90342cd617de7fc8077b1304643c2d85c1e
url: "https://pub.dev"
source: hosted
- version: "1.1.1"
+ version: "1.1.2"
shelf_web_socket:
dependency: transitive
description:
name: shelf_web_socket
- sha256: a988c0e8d8ffbdb8a28aa7ec8e449c260f3deb808781fe1284d22c5bba7156e8
+ sha256: "9ca081be41c60190ebcb4766b2486a7d50261db7bd0f5d9615f2d653637a84c1"
url: "https://pub.dev"
source: hosted
- version: "1.0.3"
+ version: "1.0.4"
sign_in_with_apple:
dependency: transitive
description:
@@ -1362,10 +1298,10 @@ packages:
dependency: transitive
description:
name: source_gen
- sha256: "2d79738b6bbf38a43920e2b8d189e9a3ce6cc201f4b8fc76be5e4fe377b1c38d"
+ sha256: "373f96cf5a8744bc9816c1ff41cf5391bbdbe3d7a96fe98c622b6738a8a7bd33"
url: "https://pub.dev"
source: hosted
- version: "1.2.6"
+ version: "1.3.2"
source_helper:
dependency: transitive
description:
@@ -1410,10 +1346,10 @@ packages:
dependency: transitive
description:
name: storage_client
- sha256: "4ed4dc8a990d178c96962319d6d8c267c3e206fca2c2b98660bad6e001220ffc"
+ sha256: e14434a4cc16b01f2e96f3c646e43fb0bb16624b279a65a34da889cffe4b083c
url: "https://pub.dev"
source: hosted
- version: "1.3.1"
+ version: "1.4.0"
stream_channel:
dependency: transitive
description:
@@ -1442,26 +1378,26 @@ packages:
dependency: "direct main"
description:
name: styled_widget
- sha256: a22407bb8e7450ad62e24232d8e02a12c399644d3144b6df742dc641e3f955ef
+ sha256: "4d439802919b6ccf10d1488798656da8804633b03012682dd1c8ca70a084aa84"
url: "https://pub.dev"
source: hosted
- version: "0.3.1+2"
+ version: "0.4.1"
supabase:
dependency: transitive
description:
name: supabase
- sha256: "403739cdfea48ba633450e5b191ceeaae81ac10ec89166c0e109235b3e1532f3"
+ sha256: "8f89e406d1c0101409a9c5d5560ed391d6d3636d2e077336905f3eee18622073"
url: "https://pub.dev"
source: hosted
- version: "1.8.1"
+ version: "1.9.0"
supabase_flutter:
dependency: "direct main"
description:
name: supabase_flutter
- sha256: "7cbdd9a7264dd5b7ab5a6e2da63346054b8e5ddf358467c7f2bc23d5c14d732c"
+ sha256: "809c67c296d4a0690fdc8e5f952a5e18b3ebd145867f1cb3f8f80248b22a56ae"
url: "https://pub.dev"
source: hosted
- version: "1.9.1"
+ version: "1.10.0"
sync_http:
dependency: transitive
description:
@@ -1474,10 +1410,10 @@ packages:
dependency: "direct main"
description:
name: table_calendar
- sha256: "7f1270313c0cdb245b583ed8518982c01d4a7e95869b3c30abcbae3b642c45d0"
+ sha256: "1e3521a3e6d3fc7f645a58b135ab663d458ab12504f1ea7f9b4b81d47086c478"
url: "https://pub.dev"
source: hosted
- version: "3.0.8"
+ version: "3.0.9"
term_glyph:
dependency: transitive
description:
@@ -1490,26 +1426,26 @@ packages:
dependency: transitive
description:
name: test
- sha256: a5fcd2d25eeadbb6589e80198a47d6a464ba3e2049da473943b8af9797900c2d
+ sha256: "3dac9aecf2c3991d09b9cdde4f98ded7b30804a88a0d7e4e7e1678e78d6b97f4"
url: "https://pub.dev"
source: hosted
- version: "1.22.0"
+ version: "1.24.1"
test_api:
dependency: transitive
description:
name: test_api
- sha256: ad540f65f92caa91bf21dfc8ffb8c589d6e4dc0c2267818b4cc2792857706206
+ sha256: eb6ac1540b26de412b3403a163d919ba86f6a973fe6cc50ae3541b80092fdcfb
url: "https://pub.dev"
source: hosted
- version: "0.4.16"
+ version: "0.5.1"
test_core:
dependency: transitive
description:
name: test_core
- sha256: "0ef9755ec6d746951ba0aabe62f874b707690b5ede0fecc818b138fcc9b14888"
+ sha256: "5138dbffb77b2289ecb12b81c11ba46036590b72a64a7a90d6ffb880f1a29e93"
url: "https://pub.dev"
source: hosted
- version: "0.4.20"
+ version: "0.5.1"
textfield_tags:
dependency: "direct main"
description:
@@ -1518,14 +1454,6 @@ packages:
url: "https://pub.dev"
source: hosted
version: "2.0.2"
- textstyle_extensions:
- dependency: "direct main"
- description:
- name: textstyle_extensions
- sha256: b0538352844fb4d1d0eea82f7bc6b96e4dae03a3a071247e4dcc85ec627b2c6c
- url: "https://pub.dev"
- source: hosted
- version: "2.0.0-nullsafety"
time:
dependency: "direct main"
description:
@@ -1543,7 +1471,7 @@ packages:
source: hosted
version: "1.0.1"
tuple:
- dependency: "direct main"
+ dependency: transitive
description:
name: tuple
sha256: "0ea99cd2f9352b2586583ab2ce6489d1f95a5f6de6fb9492faaf97ae2060f0aa"
@@ -1554,10 +1482,10 @@ packages:
dependency: transitive
description:
name: typed_data
- sha256: "26f87ade979c47a150c9eaab93ccd2bebe70a27dc0b4b29517f2904f04eb11a5"
+ sha256: facc8d6582f16042dd49f2463ff1bd6e2c9ef9f3d5da3d9b087e244a7b564b3c
url: "https://pub.dev"
source: hosted
- version: "1.3.1"
+ version: "1.3.2"
universal_io:
dependency: transitive
description:
@@ -1578,42 +1506,42 @@ packages:
dependency: "direct main"
description:
name: url_launcher
- sha256: "75f2846facd11168d007529d6cd8fcb2b750186bea046af9711f10b907e1587e"
+ sha256: eb1e00ab44303d50dd487aab67ebc575456c146c6af44422f9c13889984c00f3
url: "https://pub.dev"
source: hosted
- version: "6.1.10"
+ version: "6.1.11"
url_launcher_android:
dependency: transitive
description:
name: url_launcher_android
- sha256: dd729390aa936bf1bdf5cd1bc7468ff340263f80a2c4f569416507667de8e3c8
+ sha256: "1a5848f598acc5b7d8f7c18b8cb834ab667e59a13edc3c93e9d09cf38cc6bc87"
url: "https://pub.dev"
source: hosted
- version: "6.0.26"
+ version: "6.0.34"
url_launcher_ios:
dependency: transitive
description:
name: url_launcher_ios
- sha256: "3dedc66ca3c0bef9e6a93c0999aee102556a450afcc1b7bcfeace7a424927d92"
+ sha256: "9af7ea73259886b92199f9e42c116072f05ff9bea2dcb339ab935dfc957392c2"
url: "https://pub.dev"
source: hosted
- version: "6.1.3"
+ version: "6.1.4"
url_launcher_linux:
dependency: transitive
description:
name: url_launcher_linux
- sha256: "206fb8334a700ef7754d6a9ed119e7349bc830448098f21a69bf1b4ed038cabc"
+ sha256: "207f4ddda99b95b4d4868320a352d374b0b7e05eefad95a4a26f57da413443f5"
url: "https://pub.dev"
source: hosted
- version: "3.0.4"
+ version: "3.0.5"
url_launcher_macos:
dependency: transitive
description:
name: url_launcher_macos
- sha256: "0ef2b4f97942a16523e51256b799e9aa1843da6c60c55eefbfa9dbc2dcb8331a"
+ sha256: "91ee3e75ea9dadf38036200c5d3743518f4a5eb77a8d13fda1ee5764373f185e"
url: "https://pub.dev"
source: hosted
- version: "3.0.4"
+ version: "3.0.5"
url_launcher_platform_interface:
dependency: transitive
description:
@@ -1626,18 +1554,18 @@ packages:
dependency: transitive
description:
name: url_launcher_web
- sha256: "81fe91b6c4f84f222d186a9d23c73157dc4c8e1c71489c4d08be1ad3b228f1aa"
+ sha256: "6bb1e5d7fe53daf02a8fee85352432a40b1f868a81880e99ec7440113d5cfcab"
url: "https://pub.dev"
source: hosted
- version: "2.0.16"
+ version: "2.0.17"
url_launcher_windows:
dependency: transitive
description:
name: url_launcher_windows
- sha256: a83ba3607a507758669cfafb03f9de09bf6e6280c14d9b9cb18f013e406dcacd
+ sha256: "254708f17f7c20a9c8c471f67d86d76d4a3f9c1591aad1e15292008aceb82771"
url: "https://pub.dev"
source: hosted
- version: "3.0.5"
+ version: "3.0.6"
uuid:
dependency: transitive
description:
@@ -1650,26 +1578,26 @@ packages:
dependency: transitive
description:
name: vector_graphics
- sha256: "4cf8e60dbe4d3a693d37dff11255a172594c0793da542183cbfe7fe978ae4aaa"
+ sha256: b96f10cbdfcbd03a65758633a43e7d04574438f059b1043104b5d61b23d38a4f
url: "https://pub.dev"
source: hosted
- version: "1.1.4"
+ version: "1.1.6"
vector_graphics_codec:
dependency: transitive
description:
name: vector_graphics_codec
- sha256: "278ad5f816f58b1967396d1f78ced470e3e58c9fe4b27010102c0a595c764468"
+ sha256: "57a8e6e24662a3bdfe3b3d61257db91768700c0b8f844e235877b56480f31c69"
url: "https://pub.dev"
source: hosted
- version: "1.1.4"
+ version: "1.1.6"
vector_graphics_compiler:
dependency: transitive
description:
name: vector_graphics_compiler
- sha256: "0bf61ad56e6fd6688a2865d3ceaea396bc6a0a90ea0d7ad5049b1b76c09d6163"
+ sha256: "7430f5d834d0db4560d7b19863362cd892f1e52b43838553a3c5cdfc9ab28e5b"
url: "https://pub.dev"
source: hosted
- version: "1.1.4"
+ version: "1.1.6"
vector_math:
dependency: transitive
description:
@@ -1682,34 +1610,34 @@ packages:
dependency: transitive
description:
name: vm_service
- sha256: e7fb6c2282f7631712b69c19d1bff82f3767eea33a2321c14fa59ad67ea391c7
+ sha256: f6deed8ed625c52864792459709183da231ebf66ff0cf09e69b573227c377efe
url: "https://pub.dev"
source: hosted
- version: "9.4.0"
+ version: "11.3.0"
watcher:
dependency: transitive
description:
name: watcher
- sha256: "6a7f46926b01ce81bfc339da6a7f20afbe7733eff9846f6d6a5466aa4c6667c0"
+ sha256: "3d2ad6751b3c16cf07c7fca317a1413b3f26530319181b37e3b9039b84fc01d8"
url: "https://pub.dev"
source: hosted
- version: "1.0.2"
+ version: "1.1.0"
web_socket_channel:
dependency: transitive
description:
name: web_socket_channel
- sha256: ca49c0bc209c687b887f30527fb6a9d80040b072cc2990f34b9bec3e7663101b
+ sha256: d88238e5eac9a42bb43ca4e721edba3c08c6354d4a53063afaa568516217621b
url: "https://pub.dev"
source: hosted
- version: "2.3.0"
+ version: "2.4.0"
webdriver:
dependency: transitive
description:
name: webdriver
- sha256: ef67178f0cc7e32c1494645b11639dd1335f1d18814aa8435113a92e9ef9d841
+ sha256: "3c923e918918feeb90c4c9fdf1fe39220fa4c0e8e2c0fffaded174498ef86c49"
url: "https://pub.dev"
source: hosted
- version: "3.0.1"
+ version: "3.0.2"
webkit_inspection_protocol:
dependency: transitive
description:
@@ -1722,50 +1650,58 @@ packages:
dependency: transitive
description:
name: webview_flutter
- sha256: "1a37bdbaaf5fbe09ad8579ab09ecfd473284ce482f900b5aea27cf834386a567"
+ sha256: "5604dac1178680a34fbe4a08c7b69ec42cca6601dc300009ec9ff69bef284cc2"
url: "https://pub.dev"
source: hosted
- version: "4.2.0"
+ version: "4.2.1"
webview_flutter_android:
dependency: transitive
description:
name: webview_flutter_android
- sha256: "1acea8def62592123e2fbbca164ed8681a98a890bdcbb88f916d5b4a22687759"
+ sha256: "57a22c86065375c1598b57224f92d6008141be0c877c64100de8bfb6f71083d8"
url: "https://pub.dev"
source: hosted
- version: "3.7.0"
+ version: "3.7.1"
webview_flutter_platform_interface:
dependency: transitive
description:
name: webview_flutter_platform_interface
- sha256: "78715dc442b7849dbde74e92bb67de1cecf5addf95531c5fb474e72f5fe9a507"
+ sha256: "656e2aeaef318900fffd21468b6ddc7958c7092a642f0e7220bac328b70d4a81"
url: "https://pub.dev"
source: hosted
- version: "2.3.0"
+ version: "2.3.1"
webview_flutter_wkwebview:
dependency: transitive
description:
name: webview_flutter_wkwebview
- sha256: "4646bb68297803bdbb96d46853e8fcb560d6cb5e04153fa64581535767875dfe"
+ sha256: "6bbc6ade302b842999b27cbaa7171241c273deea8a9c73f92ceb3d811c767de2"
url: "https://pub.dev"
source: hosted
- version: "3.4.3"
+ version: "3.4.4"
win32:
dependency: transitive
description:
name: win32
- sha256: "6b75ac2ddd42f5c226fdaf4498a2b04071c06f1f2b8f7ab1c3f77cc7f2285ff1"
+ sha256: "5a751eddf9db89b3e5f9d50c20ab8612296e4e8db69009788d6c8b060a84191c"
url: "https://pub.dev"
source: hosted
- version: "2.7.0"
+ version: "4.1.4"
+ win32_registry:
+ dependency: transitive
+ description:
+ name: win32_registry
+ sha256: "1c52f994bdccb77103a6231ad4ea331a244dbcef5d1f37d8462f713143b0bfae"
+ url: "https://pub.dev"
+ source: hosted
+ version: "1.1.0"
window_manager:
dependency: "direct main"
description:
name: window_manager
- sha256: "492806c69879f0d28e95472bbe5e8d5940ac8c6e99cc07052fe14946974555ba"
+ sha256: "95096fede562cbb65f30d38b62d819a458f59ba9fe4a317f6cee669710f6676b"
url: "https://pub.dev"
source: hosted
- version: "0.3.1"
+ version: "0.3.4"
xdg_directories:
dependency: transitive
description:
@@ -1778,26 +1714,26 @@ packages:
dependency: transitive
description:
name: xml
- sha256: ac0e3f4bf00ba2708c33fbabbbe766300e509f8c82dbd4ab6525039813f7e2fb
+ sha256: "5bc72e1e45e941d825fd7468b9b4cc3b9327942649aeb6fc5cdbf135f0a86e84"
url: "https://pub.dev"
source: hosted
- version: "6.1.0"
+ version: "6.3.0"
yaml:
dependency: transitive
description:
name: yaml
- sha256: "23812a9b125b48d4007117254bca50abb6c712352927eece9e155207b1db2370"
+ sha256: "75769501ea3489fca56601ff33454fe45507ea3bfb014161abc3b43ae25989d5"
url: "https://pub.dev"
source: hosted
- version: "3.1.1"
+ version: "3.1.2"
yet_another_json_isolate:
dependency: transitive
description:
name: yet_another_json_isolate
- sha256: "94ba4947ac1ce44bd6a1634d9df712e07b9b5025ba12abd6750be77ba5c08f18"
+ sha256: "7809f6517bafd0a7b3d0be63cd5f952ae5c030d682250e8aa9ed7002eaac5ff8"
url: "https://pub.dev"
source: hosted
- version: "1.0.4"
+ version: "1.1.0"
sdks:
- dart: ">=2.19.0 <3.0.0"
- flutter: ">=3.7.0"
+ dart: ">=3.0.0 <4.0.0"
+ flutter: ">=3.10.1"
diff --git a/frontend/appflowy_flutter/pubspec.yaml b/frontend/appflowy_flutter/pubspec.yaml
index a69a56cc87..9d5a473a00 100644
--- a/frontend/appflowy_flutter/pubspec.yaml
+++ b/frontend/appflowy_flutter/pubspec.yaml
@@ -18,7 +18,7 @@ publish_to: "none" # Remove this line if you wish to publish to pub.dev
version: 0.1.5
environment:
- sdk: ">=2.19.0 <3.0.0"
+ sdk: ">=3.0.0 <4.0.0"
# Dependencies specify other packages that your package needs in order to work.
# To automatically upgrade your package dependencies to the latest versions
@@ -42,72 +42,64 @@ dependencies:
git:
url: https://github.com/AppFlowy-IO/appflowy-board.git
ref: a183c57
- # appflowy_editor: ^0.1.9
appflowy_editor:
- # path: /Users/lucas.xu/Desktop/appflowy-editor
git:
- url: https://github.com/LucasXu0/appflowy-editor.git
- ref: 09e91c
+ url: https://github.com/AppFlowy-IO/appflowy-editor.git
+ ref: 30ce149
appflowy_popover:
path: packages/appflowy_popover
# third party packages
- intl: ^0.17.0
- time: "^2.0.0"
- equatable: "^2.0.3"
- freezed_annotation: ^2.1.0
- get_it: "^7.1.3"
- flutter_bloc: "^8.0.1"
+ intl: ^0.18.0
+ time: ^2.1.3
+ equatable: ^2.0.5
+ freezed_annotation: ^2.2.0
+ get_it: ^7.6.0
+ flutter_bloc: ^8.1.3
flutter_math_fork:
git:
- url: https://github.com/LucasXu0/flutter_math_fork.git
- ref: master
+ url: https://github.com/xazin/flutter_math_fork.git
+ ref: de24059
dartz: ^0.10.1
- provider: ^6.0.1
- path_provider: ^2.0.1
- sized_context: ^1.0.0+1
- styled_widget: "^0.3.1"
+ provider: ^6.0.5
+ path_provider: ^2.0.15
+ sized_context: ^1.0.0+4
+ styled_widget: ^0.4.1
expandable: ^5.0.1
flutter_colorpicker: ^1.0.3
highlight: ^0.7.0
- package_info_plus: ^1.3.0
- url_launcher: ^6.0.2
- # file_picker: ^4.2.1
+ package_info_plus: ^4.0.1
+ url_launcher: ^6.1.11
clipboard: ^0.1.3
- connectivity_plus: ^3.0.3
+ connectivity_plus: ^4.0.1
connectivity_plus_platform_interface: ^1.2.2
- easy_localization: ^3.0.0
+ easy_localization: ^3.0.2
textfield_tags: ^2.0.2
- # The following adds the Cupertino Icons font to your application.
- # Use with the CupertinoIcons class for iOS style icons.
- cupertino_icons: ^1.0.2
- device_info_plus: ^4.0.0
- fluttertoast: ^8.0.9
- table_calendar: ^3.0.5
+ device_info_plus: ^9.0.1
+ fluttertoast: ^8.2.2
+ json_annotation: ^4.8.1
+ table_calendar: ^3.0.9
reorderables: ^0.6.0
linked_scroll_controller: ^0.2.0
hotkey_manager: ^0.1.7
- fixnum: ^1.0.1
- tuple: ^2.0.0
+ fixnum: ^1.1.0
protobuf: "2.0.0"
charcode: ^1.3.1
- collection: ^1.16.0
- bloc: ^8.1.0
- textstyle_extensions: "2.0.0-nullsafety"
- shared_preferences: ^2.0.15
- google_fonts: ^4.0.3
- file_picker: <=5.0.0
- percent_indicator: ^4.0.1
- calendar_view: ^1.0.1
- window_manager: ^0.3.0
- http: ^0.13.5
- json_annotation: ^4.7.0
- path: ^1.8.2
+ collection: ^1.17.1
+ bloc: ^8.1.2
+ shared_preferences: ^2.1.1
+ google_fonts: ^4.0.5
+ file_picker: ^5.3.1
+ percent_indicator: ^4.2.3
+ calendar_view: ^1.0.3
+ window_manager: ^0.3.4
+ http: ^1.0.0
+ path: ^1.8.3
mocktail: ^0.3.0
- archive: ^3.3.0
- flutter_svg: ^2.0.5
+ archive: ^3.3.7
+ flutter_svg: ^2.0.6
nanoid: ^1.0.0
- supabase_flutter: ^1.9.1
+ supabase_flutter: ^1.10.0
envied: ^0.3.0+3
dev_dependencies:
@@ -117,12 +109,15 @@ dev_dependencies:
sdk: flutter
integration_test:
sdk: flutter
- build_runner: ^2.3.3
- freezed: ^2.1.0+1
- bloc_test: ^9.0.2
- json_serializable: ^6.5.4
+ build_runner: ^2.4.4
+ freezed: ^2.3.4
+ bloc_test: ^9.1.2
+ json_serializable: ^6.7.0
envied_generator: ^0.3.0+3
+dependency_overrides:
+ http: ^1.0.0
+
# The "flutter_lints" package below contains a set of recommended lints to
# encourage good coding practices. The lint set provided by the package is
# activated in the `analysis_options.yaml` file located at the root of your
diff --git a/frontend/appflowy_flutter/test/util.dart b/frontend/appflowy_flutter/test/util.dart
index fa73dd2074..257bf0c876 100644
--- a/frontend/appflowy_flutter/test/util.dart
+++ b/frontend/appflowy_flutter/test/util.dart
@@ -102,8 +102,9 @@ class AppFlowyUnitTest {
void _pathProviderInitialized() {
const MethodChannel channel =
MethodChannel('plugins.flutter.io/path_provider');
- channel.setMockMethodCallHandler((MethodCall methodCall) async {
- return ".";
+ TestDefaultBinaryMessengerBinding.instance.defaultBinaryMessenger
+ .setMockMethodCallHandler(channel, (MethodCall methodCall) async {
+ return '.';
});
}
diff --git a/frontend/scripts/docker-buildfiles/Dockerfile b/frontend/scripts/docker-buildfiles/Dockerfile
index ad02abcd32..7b98e0b2b8 100644
--- a/frontend/scripts/docker-buildfiles/Dockerfile
+++ b/frontend/scripts/docker-buildfiles/Dockerfile
@@ -38,7 +38,7 @@ RUN source ~/.cargo/env && \
RUN sudo pacman -S --noconfirm git tar gtk3
RUN curl -sSfL \
--output flutter.tar.xz \
- https://storage.googleapis.com/flutter_infra_release/releases/stable/linux/flutter_linux_3.7.5-stable.tar.xz && \
+ https://storage.googleapis.com/flutter_infra_release/releases/stable/linux/flutter_linux_3.10.1-stable.tar.xz && \
tar -xf flutter.tar.xz && \
rm flutter.tar.xz
RUN flutter config --enable-linux-desktop
diff --git a/frontend/scripts/generate_language_files.cmd b/frontend/scripts/generate_language_files.cmd
index 927e3f3fc3..a208ac7160 100644
--- a/frontend/scripts/generate_language_files.cmd
+++ b/frontend/scripts/generate_language_files.cmd
@@ -1,5 +1,5 @@
echo 'Generating language files'
cd appflowy_flutter
-call flutter pub run easy_localization:generate -S assets/translations/
-call flutter pub run easy_localization:generate -f keys -o locale_keys.g.dart -S assets/translations/ -s en.json
\ No newline at end of file
+call dart run easy_localization:generate -S assets/translations/
+call dart run easy_localization:generate -f keys -o locale_keys.g.dart -S assets/translations/ -s en.json
\ No newline at end of file
diff --git a/frontend/scripts/generate_language_files.sh b/frontend/scripts/generate_language_files.sh
index 550454447c..88baca3001 100644
--- a/frontend/scripts/generate_language_files.sh
+++ b/frontend/scripts/generate_language_files.sh
@@ -2,5 +2,5 @@
#!/usr/bin/env fish
echo 'Generating language files'
cd appflowy_flutter
-flutter pub run easy_localization:generate -S assets/translations/
-flutter pub run easy_localization:generate -f keys -o locale_keys.g.dart -S assets/translations -s en.json
+dart run easy_localization:generate -S assets/translations/
+dart run easy_localization:generate -f keys -o locale_keys.g.dart -S assets/translations -s en.json
diff --git a/frontend/scripts/makefile/flutter.toml b/frontend/scripts/makefile/flutter.toml
index 7b7da3eea5..ca501ca7a3 100644
--- a/frontend/scripts/makefile/flutter.toml
+++ b/frontend/scripts/makefile/flutter.toml
@@ -189,8 +189,8 @@ script = [
cd appflowy_flutter
flutter clean
flutter packages pub get
- flutter packages pub run easy_localization:generate -S assets/translations/ -f keys -o locale_keys.g.dart -S assets/translations -s en.json
- flutter packages pub run build_runner build --delete-conflicting-outputs
+ dart run easy_localization:generate -S assets/translations/ -f keys -o locale_keys.g.dart -S assets/translations -s en.json
+ dart run build_runner build -d
""",
]
@@ -201,8 +201,8 @@ script = [
cd ./appflowy_flutter/
exec cmd.exe /c flutter clean
exec cmd.exe /c flutter packages pub get
- exec cmd.exe /c flutter packages pub run easy_localization:generate -S assets/translations/ -f keys -o locale_keys.g.dart -S assets/translations -s en.json
- exec cmd.exe /c flutter packages pub run build_runner build --delete-conflicting-outputs
+ exec cmd.exe /c dart run easy_localization:generate -S assets/translations/ -f keys -o locale_keys.g.dart -S assets/translations -s en.json
+ exec cmd.exe /c dart run build_runner build -d
""",
]
@@ -211,8 +211,8 @@ script_runner = "@shell"
script = [
"""
cd appflowy_flutter
- flutter packages pub run easy_localization:generate -S assets/translations/ -f keys -o locale_keys.g.dart -S assets/translations -s en.json
- flutter packages pub run build_runner build --delete-conflicting-outputs
+ dart run easy_localization:generate -S assets/translations/ -f keys -o locale_keys.g.dart -S assets/translations -s en.json
+ dart run build_runner build -d
""",
]
@@ -221,7 +221,7 @@ script_runner = "@duckscript"
script = [
"""
cd ./appflowy_flutter/
- exec cmd.exe /c flutter packages pub run easy_localization:generate -S assets/translations/ -f keys -o locale_keys.g.dart -S assets/translations -s en.json
- exec cmd.exe /c flutter packages pub run build_runner build --delete-conflicting-outputs
+ exec cmd.exe /c dart run easy_localization:generate -S assets/translations/ -f keys -o locale_keys.g.dart -S assets/translations -s en.json
+ exec cmd.exe /c dart run build_runner build -d
""",
]
diff --git a/frontend/scripts/install_dev_env/install_linux.sh b/frontend/scripts/install_dev_env/install_linux.sh
index 513aa4a957..48da5c4416 100755
--- a/frontend/scripts/install_dev_env/install_linux.sh
+++ b/frontend/scripts/install_dev_env/install_linux.sh
@@ -38,9 +38,9 @@ fi
printMessage "Setting up Flutter"
# Get the current Flutter version
FLUTTER_VERSION=$(flutter --version | grep -oP 'Flutter \K\S+')
-# Check if the current version is 3.7.5
-if [ "$FLUTTER_VERSION" = "3.7.5" ]; then
- echo "Flutter version is already 3.7.5"
+# Check if the current version is 3.10.1
+if [ "$FLUTTER_VERSION" = "3.10.1" ]; then
+ echo "Flutter version is already 3.10.1"
else
# Get the path to the Flutter SDK
FLUTTER_PATH=$(which flutter)
@@ -49,12 +49,12 @@ else
current_dir=$(pwd)
cd $FLUTTER_PATH
- # Use git to checkout version 3.7.5 of Flutter
- git checkout 3.7.5
+ # Use git to checkout version 3.10.1 of Flutter
+ git checkout 3.10.1
# Get back to current working directory
cd "$current_dir"
- echo "Switched to Flutter version 3.7.5"
+ echo "Switched to Flutter version 3.10.1"
fi
# Enable linux desktop
diff --git a/frontend/scripts/install_dev_env/install_macos.sh b/frontend/scripts/install_dev_env/install_macos.sh
index 91e8e603e4..c5d5223afc 100755
--- a/frontend/scripts/install_dev_env/install_macos.sh
+++ b/frontend/scripts/install_dev_env/install_macos.sh
@@ -41,9 +41,9 @@ printMessage "Setting up Flutter"
# Get the current Flutter version
FLUTTER_VERSION=$(flutter --version | grep -oE 'Flutter [^ ]+' | grep -oE '[^ ]+$')
-# Check if the current version is 3.7.5
-if [ "$FLUTTER_VERSION" = "3.7.5" ]; then
- echo "Flutter version is already 3.7.5"
+# Check if the current version is 3.10.1
+if [ "$FLUTTER_VERSION" = "3.10.1" ]; then
+ echo "Flutter version is already 3.10.1"
else
# Get the path to the Flutter SDK
FLUTTER_PATH=$(which flutter)
@@ -52,12 +52,12 @@ else
current_dir=$(pwd)
cd $FLUTTER_PATH
- # Use git to checkout version 3.7.5 of Flutter
- git checkout 3.7.5
+ # Use git to checkout version 3.10.1 of Flutter
+ git checkout 3.10.1
# Get back to current working directory
cd "$current_dir"
- echo "Switched to Flutter version 3.7.5"
+ echo "Switched to Flutter version 3.10.1"
fi
# Enable linux desktop
diff --git a/frontend/scripts/install_dev_env/install_windows.sh b/frontend/scripts/install_dev_env/install_windows.sh
index ac413738cb..cda76f9af0 100644
--- a/frontend/scripts/install_dev_env/install_windows.sh
+++ b/frontend/scripts/install_dev_env/install_windows.sh
@@ -48,9 +48,9 @@ fi
printMessage "Setting up Flutter"
# Get the current Flutter version
FLUTTER_VERSION=$(flutter --version | grep -oP 'Flutter \K\S+')
-# Check if the current version is 3.7.5
-if [ "$FLUTTER_VERSION" = "3.7.5" ]; then
- echo "Flutter version is already 3.7.5"
+# Check if the current version is 3.10.1
+if [ "$FLUTTER_VERSION" = "3.10.1" ]; then
+ echo "Flutter version is already 3.10.1"
else
# Get the path to the Flutter SDK
FLUTTER_PATH=$(which flutter)
@@ -59,12 +59,12 @@ else
current_dir=$(pwd)
cd $FLUTTER_PATH
- # Use git to checkout version 3.7.5 of Flutter
- git checkout 3.7.5
+ # Use git to checkout version 3.10.1 of Flutter
+ git checkout 3.10.1
# Get back to current working directory
cd "$current_dir"
- echo "Switched to Flutter version 3.7.5"
+ echo "Switched to Flutter version 3.10.1"
fi
# Add pub cache and cargo to PATH